# ruff: noqa: E501
"""
.. _emoji:

Emoji: Extract, Analyze, and Get Insights
=========================================

An emoji is worth a thousand words!
Regular expressions and helper functionality to aid in extracting and finding
emoji from text.

=======================   ====================================================================
:class:`EMOJI_ENTRIES`    A dictionary of the full emoji list together with unicode code points, textual name, group, and sub-group. Based on v15.1 https://unicode.org/Public/emoji/15.1/emoji-test.txt
:class:`emoji_df`         The same dictionary as a pandas DataFrame
:func:`extract_emoji`     A function for extracting and summarizing emoji in a text list, with statistics about frequencies and usage.
:func:`emoji_search`      A function for searching across names, groups, and sub-groups to find emoji based on your keywords of choice.
:class:`EMOJI_RAW`        A regular expression to extract the full list. See here on how it was developed: https://www.kaggle.com/eliasdabbas/how-to-create-a-python-regex-to-extract-emoji
=======================   ====================================================================


Emoji Search
------------

You can search the whole emoji database with the :func:`emoji_search` function:

.. thebe-button::
    Run this code

.. code-block::
    :class: thebe, thebe-init

    import advertools as adv

    vegetable_emoji = adv.emoji_search('vegetable')
    vegetable_emoji.head()

====  ===========  ===============  =======  ===========  ============  ==============
  ..  codepoint    status           emoji    name         group         sub_group
====  ===========  ===============  =======  ===========  ============  ==============
   0  1F951        fully-qualified  🥑       avocado      Food & Drink  food-vegetable
   1  1F346        fully-qualified  🍆       eggplant     Food & Drink  food-vegetable
   2  1F954        fully-qualified  🥔       potato       Food & Drink  food-vegetable
   3  1F955        fully-qualified  🥕       carrot       Food & Drink  food-vegetable
   4  1F33D        fully-qualified  🌽       ear of corn  Food & Drink  food-vegetable
====  ===========  ===============  =======  ===========  ============  ==============

Keep in mind that the search uses regular expression, and results might not be
exactly what you expect.

.. thebe-button::
    Run this code

.. code-block::
    :class: thebe, thebe-init

    love_emoji = adv.emoji_search('love')
    love_emoji


====  ===========  ===============  =======  ========================================  =================  ====================
  ..  codepoint    status           emoji    name                                      group              sub_group
====  ===========  ===============  =======  ========================================  =================  ====================
   0  1F48C        fully-qualified  💌       love letter                               Smileys & Emotion  emotion
   1  1F91F        fully-qualified  🤟       love-you gesture                          People & Body      hand-fingers-partial
   2  1F91F 1F3FB  fully-qualified  🤟🏻     love-you gesture: light skin tone         People & Body      hand-fingers-partial
   3  1F91F 1F3FC  fully-qualified  🤟🏼     love-you gesture: medium-light skin tone  People & Body      hand-fingers-partial
   4  1F91F 1F3FD  fully-qualified  🤟🏽     love-you gesture: medium skin tone        People & Body      hand-fingers-partial
   5  1F91F 1F3FE  fully-qualified  🤟🏾     love-you gesture: medium-dark skin tone   People & Body      hand-fingers-partial
   6  1F91F 1F3FF  fully-qualified  🤟🏿     love-you gesture: dark skin tone          People & Body      hand-fingers-partial
   7  1F340        fully-qualified  🍀       four leaf clover                          Animals & Nature   plant-other
   8  1F3E9        fully-qualified  🏩       love hotel                                Travel & Places    place-building
   9  1F94A        fully-qualified  🥊       boxing glove                              Activities         sport
  10  1F9E4        fully-qualified  🧤       gloves                                    Objects            clothing
  11  1F1F8 1F1EE  fully-qualified  🇸🇮       flag: Slovenia                            Flags              country-flag
====  ===========  ===============  =======  ========================================  =================  ====================

Extract Emoji from Text
-----------------------

Many times you might have some social media text, or any regular text
containing emoji that you want to analyze. The :func:`extract_emoji` function
does that, and returns useful information about the extracted emoji. You can
play around with the following sample text list, modify it, and explore the
different stats, and information about the extracted emoji:

.. thebe-button::
    Run this code

.. code-block::
    :class: thebe, thebe-init

    text_list = ['I feel like playing basketball 🏀',
                 'I like playing football ⚽⚽',
                 'Not feeling like sports today']

    emoji_summary = adv.extract_emoji(text_list)
    print(emoji_summary.keys())



"""

__all__ = ["extract_emoji", "emoji_search"]

import re
from collections import Counter

import pandas as pd

EMOJI_RAW = "\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F6B6\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468|\\U0001F468\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F468|\\U0001F469\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F48B\\U0000200D\\U0001F469|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F6B6\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FB\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FC\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FD\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FE\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FF\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F6B6\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FB\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FC\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FD\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FE\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FF\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F9CE\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FB\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FC\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FD\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FE\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FF\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F9CE\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FB\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FC\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FD\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FE\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FF\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FB\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FC\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FD\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FE\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FF\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F3C3\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FB\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FC\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FD\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FE\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FF\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F91D\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468|\\U0001F468\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F468|\\U0001F469\\U0000200D\\U00002764\\U0000200D\\U0001F48B\\U0000200D\\U0001F469|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FF|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F9D1\\U0001F3FE|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F468\\U0001F3FF|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FB\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FC\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FD\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FE\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FF\\U0000200D\\U00002764\\U0000200D\\U0001F469\\U0001F3FF|\\U0001F468\\U0000200D\\U0001F469\\U0000200D\\U0001F467\\U0000200D\\U0001F466|\\U0001F468\\U0000200D\\U0001F469\\U0000200D\\U0001F466\\U0000200D\\U0001F466|\\U0001F468\\U0000200D\\U0001F469\\U0000200D\\U0001F467\\U0000200D\\U0001F467|\\U0001F468\\U0000200D\\U0001F468\\U0000200D\\U0001F467\\U0000200D\\U0001F466|\\U0001F468\\U0000200D\\U0001F468\\U0000200D\\U0001F466\\U0000200D\\U0001F466|\\U0001F468\\U0000200D\\U0001F468\\U0000200D\\U0001F467\\U0000200D\\U0001F467|\\U0001F469\\U0000200D\\U0001F469\\U0000200D\\U0001F467\\U0000200D\\U0001F466|\\U0001F469\\U0000200D\\U0001F469\\U0000200D\\U0001F466\\U0000200D\\U0001F466|\\U0001F469\\U0000200D\\U0001F469\\U0000200D\\U0001F467\\U0000200D\\U0001F467|\\U0001F9D1\\U0000200D\\U0001F9D1\\U0000200D\\U0001F9D2\\U0000200D\\U0001F9D2|\\U0001F3F4\\U000E0067\\U000E0062\\U000E0065\\U000E006E\\U000E0067\\U000E007F|\\U0001F3F4\\U000E0067\\U000E0062\\U000E0073\\U000E0063\\U000E0074\\U000E007F|\\U0001F3F4\\U000E0067\\U000E0062\\U000E0077\\U000E006C\\U000E0073\\U000E007F|\\U0001F6B6\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FB\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FC\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FD\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FE\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FF\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F6B6\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FB\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FC\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FD\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FE\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FF\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F9CE\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FB\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FC\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FD\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FE\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FF\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F9CE\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FB\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FC\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FD\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FE\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FF\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F9D1\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F468\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F469\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F9D1\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F468\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F469\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F9D1\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F468\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F469\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F3C3\\U0000200D\\U00002640\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0000200D\\U00002640\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FB\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FC\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FD\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FE\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FF\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F3C3\\U0000200D\\U00002642\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0000200D\\U00002642\\U0000FE0F\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FB\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FC\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FD\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FE\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FF\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F469\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468|\\U0001F468\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F468|\\U0001F469\\U0000200D\\U00002764\\U0000FE0F\\U0000200D\\U0001F469|\\U0001F441\\U0000FE0F\\U0000200D\\U0001F5E8\\U0000FE0F|\\U0001FAF1\\U0001F3FB\\U0000200D\\U0001FAF2\\U0001F3FC|\\U0001FAF1\\U0001F3FB\\U0000200D\\U0001FAF2\\U0001F3FD|\\U0001FAF1\\U0001F3FB\\U0000200D\\U0001FAF2\\U0001F3FE|\\U0001FAF1\\U0001F3FB\\U0000200D\\U0001FAF2\\U0001F3FF|\\U0001FAF1\\U0001F3FC\\U0000200D\\U0001FAF2\\U0001F3FB|\\U0001FAF1\\U0001F3FC\\U0000200D\\U0001FAF2\\U0001F3FD|\\U0001FAF1\\U0001F3FC\\U0000200D\\U0001FAF2\\U0001F3FE|\\U0001FAF1\\U0001F3FC\\U0000200D\\U0001FAF2\\U0001F3FF|\\U0001FAF1\\U0001F3FD\\U0000200D\\U0001FAF2\\U0001F3FB|\\U0001FAF1\\U0001F3FD\\U0000200D\\U0001FAF2\\U0001F3FC|\\U0001FAF1\\U0001F3FD\\U0000200D\\U0001FAF2\\U0001F3FE|\\U0001FAF1\\U0001F3FD\\U0000200D\\U0001FAF2\\U0001F3FF|\\U0001FAF1\\U0001F3FE\\U0000200D\\U0001FAF2\\U0001F3FB|\\U0001FAF1\\U0001F3FE\\U0000200D\\U0001FAF2\\U0001F3FC|\\U0001FAF1\\U0001F3FE\\U0000200D\\U0001FAF2\\U0001F3FD|\\U0001FAF1\\U0001F3FE\\U0000200D\\U0001FAF2\\U0001F3FF|\\U0001FAF1\\U0001F3FF\\U0000200D\\U0001FAF2\\U0001F3FB|\\U0001FAF1\\U0001F3FF\\U0000200D\\U0001FAF2\\U0001F3FC|\\U0001FAF1\\U0001F3FF\\U0000200D\\U0001FAF2\\U0001F3FD|\\U0001FAF1\\U0001F3FF\\U0000200D\\U0001FAF2\\U0001F3FE|\\U0001F9D4\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D4\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D4\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D4\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D4\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D4\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D4\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D4\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D4\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D4\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F471\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F471\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F471\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F471\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F471\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F471\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F471\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F471\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F471\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F471\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64D\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64D\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64D\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64D\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64D\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64D\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64D\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64D\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64D\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64D\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64E\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64E\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64E\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64E\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64E\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64E\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64E\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64E\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64E\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64E\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F645\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F645\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F645\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F645\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F645\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F645\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F645\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F645\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F645\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F645\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F646\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F646\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F646\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F646\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F646\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F646\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F646\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F646\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F646\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F646\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F481\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F481\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F481\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F481\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F481\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F481\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F481\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F481\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F481\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F481\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64B\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64B\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64B\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64B\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64B\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64B\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64B\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64B\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64B\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64B\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CF\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CF\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CF\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CF\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CF\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CF\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CF\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CF\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CF\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CF\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F647\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F647\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F647\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F647\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F647\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F647\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F647\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F647\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F647\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F647\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F926\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F926\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F926\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F926\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F926\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F926\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F926\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F926\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F926\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F926\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F937\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F937\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F937\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F937\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F937\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F937\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F937\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F937\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F937\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F937\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002695\\U0000FE0F|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002695\\U0000FE0F|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002695\\U0000FE0F|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002695\\U0000FE0F|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002695\\U0000FE0F|\\U0001F468\\U0001F3FB\\U0000200D\\U00002695\\U0000FE0F|\\U0001F468\\U0001F3FC\\U0000200D\\U00002695\\U0000FE0F|\\U0001F468\\U0001F3FD\\U0000200D\\U00002695\\U0000FE0F|\\U0001F468\\U0001F3FE\\U0000200D\\U00002695\\U0000FE0F|\\U0001F468\\U0001F3FF\\U0000200D\\U00002695\\U0000FE0F|\\U0001F469\\U0001F3FB\\U0000200D\\U00002695\\U0000FE0F|\\U0001F469\\U0001F3FC\\U0000200D\\U00002695\\U0000FE0F|\\U0001F469\\U0001F3FD\\U0000200D\\U00002695\\U0000FE0F|\\U0001F469\\U0001F3FE\\U0000200D\\U00002695\\U0000FE0F|\\U0001F469\\U0001F3FF\\U0000200D\\U00002695\\U0000FE0F|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002696\\U0000FE0F|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002696\\U0000FE0F|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002696\\U0000FE0F|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002696\\U0000FE0F|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002696\\U0000FE0F|\\U0001F468\\U0001F3FB\\U0000200D\\U00002696\\U0000FE0F|\\U0001F468\\U0001F3FC\\U0000200D\\U00002696\\U0000FE0F|\\U0001F468\\U0001F3FD\\U0000200D\\U00002696\\U0000FE0F|\\U0001F468\\U0001F3FE\\U0000200D\\U00002696\\U0000FE0F|\\U0001F468\\U0001F3FF\\U0000200D\\U00002696\\U0000FE0F|\\U0001F469\\U0001F3FB\\U0000200D\\U00002696\\U0000FE0F|\\U0001F469\\U0001F3FC\\U0000200D\\U00002696\\U0000FE0F|\\U0001F469\\U0001F3FD\\U0000200D\\U00002696\\U0000FE0F|\\U0001F469\\U0001F3FE\\U0000200D\\U00002696\\U0000FE0F|\\U0001F469\\U0001F3FF\\U0000200D\\U00002696\\U0000FE0F|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002708\\U0000FE0F|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002708\\U0000FE0F|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002708\\U0000FE0F|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002708\\U0000FE0F|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002708\\U0000FE0F|\\U0001F468\\U0001F3FB\\U0000200D\\U00002708\\U0000FE0F|\\U0001F468\\U0001F3FC\\U0000200D\\U00002708\\U0000FE0F|\\U0001F468\\U0001F3FD\\U0000200D\\U00002708\\U0000FE0F|\\U0001F468\\U0001F3FE\\U0000200D\\U00002708\\U0000FE0F|\\U0001F468\\U0001F3FF\\U0000200D\\U00002708\\U0000FE0F|\\U0001F469\\U0001F3FB\\U0000200D\\U00002708\\U0000FE0F|\\U0001F469\\U0001F3FC\\U0000200D\\U00002708\\U0000FE0F|\\U0001F469\\U0001F3FD\\U0000200D\\U00002708\\U0000FE0F|\\U0001F469\\U0001F3FE\\U0000200D\\U00002708\\U0000FE0F|\\U0001F469\\U0001F3FF\\U0000200D\\U00002708\\U0000FE0F|\\U0001F46E\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F46E\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F46E\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F46E\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F46E\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F46E\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F46E\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F46E\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F46E\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F46E\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F575\\U0000FE0F\\U0000200D\\U00002642\\U0000FE0F|\\U0001F575\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F575\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F575\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F575\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F575\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F575\\U0000FE0F\\U0000200D\\U00002640\\U0000FE0F|\\U0001F575\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F575\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F575\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F575\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F575\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F482\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F482\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F482\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F482\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F482\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F482\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F482\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F482\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F482\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F482\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F477\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F477\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F477\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F477\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F477\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F477\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F477\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F477\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F477\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F477\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F473\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F473\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F473\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F473\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F473\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F473\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F473\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F473\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F473\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F473\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F935\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F935\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F935\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F935\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F935\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F935\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F935\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F935\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F935\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F935\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F470\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F470\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F470\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F470\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F470\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F470\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F470\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F470\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F470\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F470\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9B8\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9B8\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9B8\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9B8\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9B8\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9B8\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9B8\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9B8\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9B8\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9B8\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9B9\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9B9\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9B9\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9B9\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9B9\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9B9\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9B9\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9B9\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9B9\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9B9\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D9\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D9\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D9\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D9\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D9\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D9\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D9\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D9\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D9\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D9\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DA\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DA\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DA\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DA\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DA\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DA\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DA\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DA\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DA\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DA\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DB\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DB\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DB\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DB\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DB\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DB\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DB\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DB\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DB\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DB\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DC\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DC\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DC\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DC\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DC\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DC\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DC\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DC\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DC\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DC\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DD\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DD\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DD\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DD\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DD\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DD\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DD\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DD\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DD\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DD\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F486\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F486\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F486\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F486\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F486\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F486\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F486\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F486\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F486\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F486\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F487\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F487\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F487\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F487\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F487\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F487\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F487\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F487\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F487\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F487\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B6\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B6\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B6\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B6\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B6\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B6\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B6\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B6\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B6\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B6\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B6\\U0001F3FB\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FE\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F6B6\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F9CD\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CD\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CD\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CD\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CD\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CD\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CD\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CD\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CD\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CD\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CE\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CE\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CE\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CE\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CE\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CE\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CE\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CE\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CE\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CE\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CE\\U0001F3FB\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FE\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F9CE\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F9D1\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F468\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F469\\U0000200D\\U0001F9AF\\U0000200D\\U000027A1|\\U0001F9D1\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F468\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F469\\U0000200D\\U0001F9BC\\U0000200D\\U000027A1|\\U0001F9D1\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F468\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F469\\U0000200D\\U0001F9BD\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3C3\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3C3\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3C3\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3C3\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3C3\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3C3\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3C3\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3C3\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3C3\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3C3\\U0001F3FB\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FC\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FD\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FE\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FF\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0000200D\\U00002640\\U0000200D\\U000027A1|\\U0001F3C3\\U0000200D\\U00002642\\U0000200D\\U000027A1|\\U0001F9D6\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D6\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D6\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D6\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D6\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D6\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D6\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D6\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D6\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D6\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D7\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D7\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D7\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D7\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D7\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D7\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D7\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D7\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D7\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D7\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CC\\U0000FE0F\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CC\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CC\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CC\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CC\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CC\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CC\\U0000FE0F\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CC\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CC\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CC\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CC\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CC\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3C4\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3C4\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3C4\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3C4\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3C4\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3C4\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3C4\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3C4\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3C4\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3C4\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6A3\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6A3\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6A3\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6A3\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6A3\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6A3\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6A3\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6A3\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6A3\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6A3\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CA\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CA\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CA\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CA\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CA\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CA\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CA\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CA\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CA\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CA\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U000026F9\\U0000FE0F\\U0000200D\\U00002642\\U0000FE0F|\\U000026F9\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U000026F9\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U000026F9\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U000026F9\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U000026F9\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U000026F9\\U0000FE0F\\U0000200D\\U00002640\\U0000FE0F|\\U000026F9\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U000026F9\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U000026F9\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U000026F9\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U000026F9\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CB\\U0000FE0F\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CB\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CB\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CB\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CB\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CB\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CB\\U0000FE0F\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CB\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CB\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CB\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CB\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CB\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B4\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B4\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B4\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B4\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B4\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B4\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B4\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B4\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B4\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B4\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B5\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B5\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B5\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B5\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B5\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B5\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B5\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B5\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B5\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B5\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F938\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F938\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F938\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F938\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F938\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F938\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F938\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F938\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F938\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F938\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F93D\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F93D\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F93D\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F93D\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F93D\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F93D\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F93D\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F93D\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F93D\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F93D\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F93E\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F93E\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F93E\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F93E\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F93E\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F93E\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F93E\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F93E\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F93E\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F93E\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F939\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F939\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F939\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F939\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F939\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F939\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F939\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F939\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F939\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F939\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D8\\U0001F3FB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D8\\U0001F3FC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D8\\U0001F3FD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D8\\U0001F3FE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D8\\U0001F3FF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D8\\U0001F3FB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D8\\U0001F3FC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D8\\U0001F3FD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D8\\U0001F3FE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D8\\U0001F3FF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D1\\U0000200D\\U0001F91D\\U0000200D\\U0001F9D1|\\U0001F469\\U0000200D\\U00002764\\U0000200D\\U0001F468|\\U0001F468\\U0000200D\\U00002764\\U0000200D\\U0001F468|\\U0001F469\\U0000200D\\U00002764\\U0000200D\\U0001F469|\\U0001F468\\U0000200D\\U0001F469\\U0000200D\\U0001F466|\\U0001F468\\U0000200D\\U0001F469\\U0000200D\\U0001F467|\\U0001F468\\U0000200D\\U0001F468\\U0000200D\\U0001F466|\\U0001F468\\U0000200D\\U0001F468\\U0000200D\\U0001F467|\\U0001F469\\U0000200D\\U0001F469\\U0000200D\\U0001F466|\\U0001F469\\U0000200D\\U0001F469\\U0000200D\\U0001F467|\\U0001F468\\U0000200D\\U0001F466\\U0000200D\\U0001F466|\\U0001F468\\U0000200D\\U0001F467\\U0000200D\\U0001F466|\\U0001F468\\U0000200D\\U0001F467\\U0000200D\\U0001F467|\\U0001F469\\U0000200D\\U0001F466\\U0000200D\\U0001F466|\\U0001F469\\U0000200D\\U0001F467\\U0000200D\\U0001F466|\\U0001F469\\U0000200D\\U0001F467\\U0000200D\\U0001F467|\\U0001F9D1\\U0000200D\\U0001F9D1\\U0000200D\\U0001F9D2|\\U0001F9D1\\U0000200D\\U0001F9D2\\U0000200D\\U0001F9D2|\\U0001F3F3\\U0000FE0F\\U0000200D\\U000026A7\\U0000FE0F|\\U0001F636\\U0000200D\\U0001F32B\\U0000FE0F|\\U0001F642\\U0000200D\\U00002194\\U0000FE0F|\\U0001F642\\U0000200D\\U00002195\\U0000FE0F|\\U00002764\\U0000FE0F\\U0000200D\\U0001F525|\\U00002764\\U0000FE0F\\U0000200D\\U0001FA79|\\U0001F441\\U0000200D\\U0001F5E8\\U0000FE0F|\\U0001F441\\U0000FE0F\\U0000200D\\U0001F5E8|\\U0001F9D4\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D4\\U0001F3FB\\U0000200D\\U00002642|\\U0001F9D4\\U0001F3FC\\U0000200D\\U00002642|\\U0001F9D4\\U0001F3FD\\U0000200D\\U00002642|\\U0001F9D4\\U0001F3FE\\U0000200D\\U00002642|\\U0001F9D4\\U0001F3FF\\U0000200D\\U00002642|\\U0001F9D4\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D4\\U0001F3FB\\U0000200D\\U00002640|\\U0001F9D4\\U0001F3FC\\U0000200D\\U00002640|\\U0001F9D4\\U0001F3FD\\U0000200D\\U00002640|\\U0001F9D4\\U0001F3FE\\U0000200D\\U00002640|\\U0001F9D4\\U0001F3FF\\U0000200D\\U00002640|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F9B0|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F9B0|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F9B0|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F9B0|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F9B0|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F9B1|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F9B1|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F9B1|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F9B1|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F9B1|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F9B3|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F9B3|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F9B3|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F9B3|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F9B3|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F9B2|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F9B2|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F9B2|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F9B2|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F9B2|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F9B0|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F9B0|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F9B0|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F9B0|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F9B0|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F9B0|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F9B0|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F9B0|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F9B0|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F9B0|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F9B1|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F9B1|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F9B1|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F9B1|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F9B1|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F9B1|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F9B1|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F9B1|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F9B1|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F9B1|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F9B3|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F9B3|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F9B3|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F9B3|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F9B3|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F9B3|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F9B3|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F9B3|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F9B3|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F9B3|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F9B2|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F9B2|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F9B2|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F9B2|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F9B2|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F9B2|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F9B2|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F9B2|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F9B2|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F9B2|\\U0001F471\\U0000200D\\U00002640\\U0000FE0F|\\U0001F471\\U0001F3FB\\U0000200D\\U00002640|\\U0001F471\\U0001F3FC\\U0000200D\\U00002640|\\U0001F471\\U0001F3FD\\U0000200D\\U00002640|\\U0001F471\\U0001F3FE\\U0000200D\\U00002640|\\U0001F471\\U0001F3FF\\U0000200D\\U00002640|\\U0001F471\\U0000200D\\U00002642\\U0000FE0F|\\U0001F471\\U0001F3FB\\U0000200D\\U00002642|\\U0001F471\\U0001F3FC\\U0000200D\\U00002642|\\U0001F471\\U0001F3FD\\U0000200D\\U00002642|\\U0001F471\\U0001F3FE\\U0000200D\\U00002642|\\U0001F471\\U0001F3FF\\U0000200D\\U00002642|\\U0001F64D\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64D\\U0001F3FB\\U0000200D\\U00002642|\\U0001F64D\\U0001F3FC\\U0000200D\\U00002642|\\U0001F64D\\U0001F3FD\\U0000200D\\U00002642|\\U0001F64D\\U0001F3FE\\U0000200D\\U00002642|\\U0001F64D\\U0001F3FF\\U0000200D\\U00002642|\\U0001F64D\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64D\\U0001F3FB\\U0000200D\\U00002640|\\U0001F64D\\U0001F3FC\\U0000200D\\U00002640|\\U0001F64D\\U0001F3FD\\U0000200D\\U00002640|\\U0001F64D\\U0001F3FE\\U0000200D\\U00002640|\\U0001F64D\\U0001F3FF\\U0000200D\\U00002640|\\U0001F64E\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64E\\U0001F3FB\\U0000200D\\U00002642|\\U0001F64E\\U0001F3FC\\U0000200D\\U00002642|\\U0001F64E\\U0001F3FD\\U0000200D\\U00002642|\\U0001F64E\\U0001F3FE\\U0000200D\\U00002642|\\U0001F64E\\U0001F3FF\\U0000200D\\U00002642|\\U0001F64E\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64E\\U0001F3FB\\U0000200D\\U00002640|\\U0001F64E\\U0001F3FC\\U0000200D\\U00002640|\\U0001F64E\\U0001F3FD\\U0000200D\\U00002640|\\U0001F64E\\U0001F3FE\\U0000200D\\U00002640|\\U0001F64E\\U0001F3FF\\U0000200D\\U00002640|\\U0001F645\\U0000200D\\U00002642\\U0000FE0F|\\U0001F645\\U0001F3FB\\U0000200D\\U00002642|\\U0001F645\\U0001F3FC\\U0000200D\\U00002642|\\U0001F645\\U0001F3FD\\U0000200D\\U00002642|\\U0001F645\\U0001F3FE\\U0000200D\\U00002642|\\U0001F645\\U0001F3FF\\U0000200D\\U00002642|\\U0001F645\\U0000200D\\U00002640\\U0000FE0F|\\U0001F645\\U0001F3FB\\U0000200D\\U00002640|\\U0001F645\\U0001F3FC\\U0000200D\\U00002640|\\U0001F645\\U0001F3FD\\U0000200D\\U00002640|\\U0001F645\\U0001F3FE\\U0000200D\\U00002640|\\U0001F645\\U0001F3FF\\U0000200D\\U00002640|\\U0001F646\\U0000200D\\U00002642\\U0000FE0F|\\U0001F646\\U0001F3FB\\U0000200D\\U00002642|\\U0001F646\\U0001F3FC\\U0000200D\\U00002642|\\U0001F646\\U0001F3FD\\U0000200D\\U00002642|\\U0001F646\\U0001F3FE\\U0000200D\\U00002642|\\U0001F646\\U0001F3FF\\U0000200D\\U00002642|\\U0001F646\\U0000200D\\U00002640\\U0000FE0F|\\U0001F646\\U0001F3FB\\U0000200D\\U00002640|\\U0001F646\\U0001F3FC\\U0000200D\\U00002640|\\U0001F646\\U0001F3FD\\U0000200D\\U00002640|\\U0001F646\\U0001F3FE\\U0000200D\\U00002640|\\U0001F646\\U0001F3FF\\U0000200D\\U00002640|\\U0001F481\\U0000200D\\U00002642\\U0000FE0F|\\U0001F481\\U0001F3FB\\U0000200D\\U00002642|\\U0001F481\\U0001F3FC\\U0000200D\\U00002642|\\U0001F481\\U0001F3FD\\U0000200D\\U00002642|\\U0001F481\\U0001F3FE\\U0000200D\\U00002642|\\U0001F481\\U0001F3FF\\U0000200D\\U00002642|\\U0001F481\\U0000200D\\U00002640\\U0000FE0F|\\U0001F481\\U0001F3FB\\U0000200D\\U00002640|\\U0001F481\\U0001F3FC\\U0000200D\\U00002640|\\U0001F481\\U0001F3FD\\U0000200D\\U00002640|\\U0001F481\\U0001F3FE\\U0000200D\\U00002640|\\U0001F481\\U0001F3FF\\U0000200D\\U00002640|\\U0001F64B\\U0000200D\\U00002642\\U0000FE0F|\\U0001F64B\\U0001F3FB\\U0000200D\\U00002642|\\U0001F64B\\U0001F3FC\\U0000200D\\U00002642|\\U0001F64B\\U0001F3FD\\U0000200D\\U00002642|\\U0001F64B\\U0001F3FE\\U0000200D\\U00002642|\\U0001F64B\\U0001F3FF\\U0000200D\\U00002642|\\U0001F64B\\U0000200D\\U00002640\\U0000FE0F|\\U0001F64B\\U0001F3FB\\U0000200D\\U00002640|\\U0001F64B\\U0001F3FC\\U0000200D\\U00002640|\\U0001F64B\\U0001F3FD\\U0000200D\\U00002640|\\U0001F64B\\U0001F3FE\\U0000200D\\U00002640|\\U0001F64B\\U0001F3FF\\U0000200D\\U00002640|\\U0001F9CF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CF\\U0001F3FB\\U0000200D\\U00002642|\\U0001F9CF\\U0001F3FC\\U0000200D\\U00002642|\\U0001F9CF\\U0001F3FD\\U0000200D\\U00002642|\\U0001F9CF\\U0001F3FE\\U0000200D\\U00002642|\\U0001F9CF\\U0001F3FF\\U0000200D\\U00002642|\\U0001F9CF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CF\\U0001F3FB\\U0000200D\\U00002640|\\U0001F9CF\\U0001F3FC\\U0000200D\\U00002640|\\U0001F9CF\\U0001F3FD\\U0000200D\\U00002640|\\U0001F9CF\\U0001F3FE\\U0000200D\\U00002640|\\U0001F9CF\\U0001F3FF\\U0000200D\\U00002640|\\U0001F647\\U0000200D\\U00002642\\U0000FE0F|\\U0001F647\\U0001F3FB\\U0000200D\\U00002642|\\U0001F647\\U0001F3FC\\U0000200D\\U00002642|\\U0001F647\\U0001F3FD\\U0000200D\\U00002642|\\U0001F647\\U0001F3FE\\U0000200D\\U00002642|\\U0001F647\\U0001F3FF\\U0000200D\\U00002642|\\U0001F647\\U0000200D\\U00002640\\U0000FE0F|\\U0001F647\\U0001F3FB\\U0000200D\\U00002640|\\U0001F647\\U0001F3FC\\U0000200D\\U00002640|\\U0001F647\\U0001F3FD\\U0000200D\\U00002640|\\U0001F647\\U0001F3FE\\U0000200D\\U00002640|\\U0001F647\\U0001F3FF\\U0000200D\\U00002640|\\U0001F926\\U0000200D\\U00002642\\U0000FE0F|\\U0001F926\\U0001F3FB\\U0000200D\\U00002642|\\U0001F926\\U0001F3FC\\U0000200D\\U00002642|\\U0001F926\\U0001F3FD\\U0000200D\\U00002642|\\U0001F926\\U0001F3FE\\U0000200D\\U00002642|\\U0001F926\\U0001F3FF\\U0000200D\\U00002642|\\U0001F926\\U0000200D\\U00002640\\U0000FE0F|\\U0001F926\\U0001F3FB\\U0000200D\\U00002640|\\U0001F926\\U0001F3FC\\U0000200D\\U00002640|\\U0001F926\\U0001F3FD\\U0000200D\\U00002640|\\U0001F926\\U0001F3FE\\U0000200D\\U00002640|\\U0001F926\\U0001F3FF\\U0000200D\\U00002640|\\U0001F937\\U0000200D\\U00002642\\U0000FE0F|\\U0001F937\\U0001F3FB\\U0000200D\\U00002642|\\U0001F937\\U0001F3FC\\U0000200D\\U00002642|\\U0001F937\\U0001F3FD\\U0000200D\\U00002642|\\U0001F937\\U0001F3FE\\U0000200D\\U00002642|\\U0001F937\\U0001F3FF\\U0000200D\\U00002642|\\U0001F937\\U0000200D\\U00002640\\U0000FE0F|\\U0001F937\\U0001F3FB\\U0000200D\\U00002640|\\U0001F937\\U0001F3FC\\U0000200D\\U00002640|\\U0001F937\\U0001F3FD\\U0000200D\\U00002640|\\U0001F937\\U0001F3FE\\U0000200D\\U00002640|\\U0001F937\\U0001F3FF\\U0000200D\\U00002640|\\U0001F9D1\\U0000200D\\U00002695\\U0000FE0F|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002695|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002695|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002695|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002695|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002695|\\U0001F468\\U0000200D\\U00002695\\U0000FE0F|\\U0001F468\\U0001F3FB\\U0000200D\\U00002695|\\U0001F468\\U0001F3FC\\U0000200D\\U00002695|\\U0001F468\\U0001F3FD\\U0000200D\\U00002695|\\U0001F468\\U0001F3FE\\U0000200D\\U00002695|\\U0001F468\\U0001F3FF\\U0000200D\\U00002695|\\U0001F469\\U0000200D\\U00002695\\U0000FE0F|\\U0001F469\\U0001F3FB\\U0000200D\\U00002695|\\U0001F469\\U0001F3FC\\U0000200D\\U00002695|\\U0001F469\\U0001F3FD\\U0000200D\\U00002695|\\U0001F469\\U0001F3FE\\U0000200D\\U00002695|\\U0001F469\\U0001F3FF\\U0000200D\\U00002695|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F393|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F393|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F393|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F393|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F393|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F393|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F393|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F393|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F393|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F393|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F393|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F393|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F393|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F393|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F393|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F3EB|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F3EB|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F3EB|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F3EB|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F3EB|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F3EB|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F3EB|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F3EB|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F3EB|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F3EB|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F3EB|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F3EB|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F3EB|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F3EB|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F3EB|\\U0001F9D1\\U0000200D\\U00002696\\U0000FE0F|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002696|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002696|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002696|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002696|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002696|\\U0001F468\\U0000200D\\U00002696\\U0000FE0F|\\U0001F468\\U0001F3FB\\U0000200D\\U00002696|\\U0001F468\\U0001F3FC\\U0000200D\\U00002696|\\U0001F468\\U0001F3FD\\U0000200D\\U00002696|\\U0001F468\\U0001F3FE\\U0000200D\\U00002696|\\U0001F468\\U0001F3FF\\U0000200D\\U00002696|\\U0001F469\\U0000200D\\U00002696\\U0000FE0F|\\U0001F469\\U0001F3FB\\U0000200D\\U00002696|\\U0001F469\\U0001F3FC\\U0000200D\\U00002696|\\U0001F469\\U0001F3FD\\U0000200D\\U00002696|\\U0001F469\\U0001F3FE\\U0000200D\\U00002696|\\U0001F469\\U0001F3FF\\U0000200D\\U00002696|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F33E|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F33E|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F33E|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F33E|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F33E|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F33E|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F33E|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F33E|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F33E|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F33E|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F33E|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F33E|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F33E|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F33E|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F33E|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F373|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F373|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F373|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F373|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F373|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F373|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F373|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F373|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F373|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F373|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F373|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F373|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F373|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F373|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F373|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F527|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F527|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F527|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F527|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F527|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F527|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F527|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F527|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F527|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F527|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F527|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F527|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F527|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F527|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F527|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F3ED|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F3ED|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F3ED|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F3ED|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F3ED|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F3ED|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F3ED|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F3ED|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F3ED|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F3ED|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F3ED|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F3ED|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F3ED|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F3ED|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F3ED|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F4BC|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F4BC|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F4BC|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F4BC|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F4BC|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F4BC|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F4BC|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F4BC|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F4BC|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F4BC|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F4BC|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F4BC|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F4BC|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F4BC|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F4BC|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F52C|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F52C|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F52C|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F52C|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F52C|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F52C|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F52C|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F52C|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F52C|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F52C|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F52C|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F52C|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F52C|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F52C|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F52C|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F4BB|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F4BB|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F4BB|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F4BB|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F4BB|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F4BB|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F4BB|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F4BB|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F4BB|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F4BB|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F4BB|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F4BB|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F4BB|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F4BB|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F4BB|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F3A4|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F3A4|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F3A4|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F3A4|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F3A4|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F3A4|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F3A4|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F3A4|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F3A4|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F3A4|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F3A4|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F3A4|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F3A4|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F3A4|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F3A4|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F3A8|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F3A8|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F3A8|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F3A8|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F3A8|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F3A8|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F3A8|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F3A8|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F3A8|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F3A8|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F3A8|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F3A8|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F3A8|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F3A8|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F3A8|\\U0001F9D1\\U0000200D\\U00002708\\U0000FE0F|\\U0001F9D1\\U0001F3FB\\U0000200D\\U00002708|\\U0001F9D1\\U0001F3FC\\U0000200D\\U00002708|\\U0001F9D1\\U0001F3FD\\U0000200D\\U00002708|\\U0001F9D1\\U0001F3FE\\U0000200D\\U00002708|\\U0001F9D1\\U0001F3FF\\U0000200D\\U00002708|\\U0001F468\\U0000200D\\U00002708\\U0000FE0F|\\U0001F468\\U0001F3FB\\U0000200D\\U00002708|\\U0001F468\\U0001F3FC\\U0000200D\\U00002708|\\U0001F468\\U0001F3FD\\U0000200D\\U00002708|\\U0001F468\\U0001F3FE\\U0000200D\\U00002708|\\U0001F468\\U0001F3FF\\U0000200D\\U00002708|\\U0001F469\\U0000200D\\U00002708\\U0000FE0F|\\U0001F469\\U0001F3FB\\U0000200D\\U00002708|\\U0001F469\\U0001F3FC\\U0000200D\\U00002708|\\U0001F469\\U0001F3FD\\U0000200D\\U00002708|\\U0001F469\\U0001F3FE\\U0000200D\\U00002708|\\U0001F469\\U0001F3FF\\U0000200D\\U00002708|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F680|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F680|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F680|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F680|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F680|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F680|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F680|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F680|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F680|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F680|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F680|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F680|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F680|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F680|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F680|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F692|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F692|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F692|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F692|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F692|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F692|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F692|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F692|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F692|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F692|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F692|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F692|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F692|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F692|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F692|\\U0001F46E\\U0000200D\\U00002642\\U0000FE0F|\\U0001F46E\\U0001F3FB\\U0000200D\\U00002642|\\U0001F46E\\U0001F3FC\\U0000200D\\U00002642|\\U0001F46E\\U0001F3FD\\U0000200D\\U00002642|\\U0001F46E\\U0001F3FE\\U0000200D\\U00002642|\\U0001F46E\\U0001F3FF\\U0000200D\\U00002642|\\U0001F46E\\U0000200D\\U00002640\\U0000FE0F|\\U0001F46E\\U0001F3FB\\U0000200D\\U00002640|\\U0001F46E\\U0001F3FC\\U0000200D\\U00002640|\\U0001F46E\\U0001F3FD\\U0000200D\\U00002640|\\U0001F46E\\U0001F3FE\\U0000200D\\U00002640|\\U0001F46E\\U0001F3FF\\U0000200D\\U00002640|\\U0001F575\\U0000200D\\U00002642\\U0000FE0F|\\U0001F575\\U0000FE0F\\U0000200D\\U00002642|\\U0001F575\\U0001F3FB\\U0000200D\\U00002642|\\U0001F575\\U0001F3FC\\U0000200D\\U00002642|\\U0001F575\\U0001F3FD\\U0000200D\\U00002642|\\U0001F575\\U0001F3FE\\U0000200D\\U00002642|\\U0001F575\\U0001F3FF\\U0000200D\\U00002642|\\U0001F575\\U0000200D\\U00002640\\U0000FE0F|\\U0001F575\\U0000FE0F\\U0000200D\\U00002640|\\U0001F575\\U0001F3FB\\U0000200D\\U00002640|\\U0001F575\\U0001F3FC\\U0000200D\\U00002640|\\U0001F575\\U0001F3FD\\U0000200D\\U00002640|\\U0001F575\\U0001F3FE\\U0000200D\\U00002640|\\U0001F575\\U0001F3FF\\U0000200D\\U00002640|\\U0001F482\\U0000200D\\U00002642\\U0000FE0F|\\U0001F482\\U0001F3FB\\U0000200D\\U00002642|\\U0001F482\\U0001F3FC\\U0000200D\\U00002642|\\U0001F482\\U0001F3FD\\U0000200D\\U00002642|\\U0001F482\\U0001F3FE\\U0000200D\\U00002642|\\U0001F482\\U0001F3FF\\U0000200D\\U00002642|\\U0001F482\\U0000200D\\U00002640\\U0000FE0F|\\U0001F482\\U0001F3FB\\U0000200D\\U00002640|\\U0001F482\\U0001F3FC\\U0000200D\\U00002640|\\U0001F482\\U0001F3FD\\U0000200D\\U00002640|\\U0001F482\\U0001F3FE\\U0000200D\\U00002640|\\U0001F482\\U0001F3FF\\U0000200D\\U00002640|\\U0001F477\\U0000200D\\U00002642\\U0000FE0F|\\U0001F477\\U0001F3FB\\U0000200D\\U00002642|\\U0001F477\\U0001F3FC\\U0000200D\\U00002642|\\U0001F477\\U0001F3FD\\U0000200D\\U00002642|\\U0001F477\\U0001F3FE\\U0000200D\\U00002642|\\U0001F477\\U0001F3FF\\U0000200D\\U00002642|\\U0001F477\\U0000200D\\U00002640\\U0000FE0F|\\U0001F477\\U0001F3FB\\U0000200D\\U00002640|\\U0001F477\\U0001F3FC\\U0000200D\\U00002640|\\U0001F477\\U0001F3FD\\U0000200D\\U00002640|\\U0001F477\\U0001F3FE\\U0000200D\\U00002640|\\U0001F477\\U0001F3FF\\U0000200D\\U00002640|\\U0001F473\\U0000200D\\U00002642\\U0000FE0F|\\U0001F473\\U0001F3FB\\U0000200D\\U00002642|\\U0001F473\\U0001F3FC\\U0000200D\\U00002642|\\U0001F473\\U0001F3FD\\U0000200D\\U00002642|\\U0001F473\\U0001F3FE\\U0000200D\\U00002642|\\U0001F473\\U0001F3FF\\U0000200D\\U00002642|\\U0001F473\\U0000200D\\U00002640\\U0000FE0F|\\U0001F473\\U0001F3FB\\U0000200D\\U00002640|\\U0001F473\\U0001F3FC\\U0000200D\\U00002640|\\U0001F473\\U0001F3FD\\U0000200D\\U00002640|\\U0001F473\\U0001F3FE\\U0000200D\\U00002640|\\U0001F473\\U0001F3FF\\U0000200D\\U00002640|\\U0001F935\\U0000200D\\U00002642\\U0000FE0F|\\U0001F935\\U0001F3FB\\U0000200D\\U00002642|\\U0001F935\\U0001F3FC\\U0000200D\\U00002642|\\U0001F935\\U0001F3FD\\U0000200D\\U00002642|\\U0001F935\\U0001F3FE\\U0000200D\\U00002642|\\U0001F935\\U0001F3FF\\U0000200D\\U00002642|\\U0001F935\\U0000200D\\U00002640\\U0000FE0F|\\U0001F935\\U0001F3FB\\U0000200D\\U00002640|\\U0001F935\\U0001F3FC\\U0000200D\\U00002640|\\U0001F935\\U0001F3FD\\U0000200D\\U00002640|\\U0001F935\\U0001F3FE\\U0000200D\\U00002640|\\U0001F935\\U0001F3FF\\U0000200D\\U00002640|\\U0001F470\\U0000200D\\U00002642\\U0000FE0F|\\U0001F470\\U0001F3FB\\U0000200D\\U00002642|\\U0001F470\\U0001F3FC\\U0000200D\\U00002642|\\U0001F470\\U0001F3FD\\U0000200D\\U00002642|\\U0001F470\\U0001F3FE\\U0000200D\\U00002642|\\U0001F470\\U0001F3FF\\U0000200D\\U00002642|\\U0001F470\\U0000200D\\U00002640\\U0000FE0F|\\U0001F470\\U0001F3FB\\U0000200D\\U00002640|\\U0001F470\\U0001F3FC\\U0000200D\\U00002640|\\U0001F470\\U0001F3FD\\U0000200D\\U00002640|\\U0001F470\\U0001F3FE\\U0000200D\\U00002640|\\U0001F470\\U0001F3FF\\U0000200D\\U00002640|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F37C|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F37C|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F37C|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F37C|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F37C|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F37C|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F37C|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F37C|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F37C|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F37C|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F37C|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F37C|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F37C|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F37C|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F37C|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F384|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F384|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F384|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F384|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F384|\\U0001F9B8\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9B8\\U0001F3FB\\U0000200D\\U00002642|\\U0001F9B8\\U0001F3FC\\U0000200D\\U00002642|\\U0001F9B8\\U0001F3FD\\U0000200D\\U00002642|\\U0001F9B8\\U0001F3FE\\U0000200D\\U00002642|\\U0001F9B8\\U0001F3FF\\U0000200D\\U00002642|\\U0001F9B8\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9B8\\U0001F3FB\\U0000200D\\U00002640|\\U0001F9B8\\U0001F3FC\\U0000200D\\U00002640|\\U0001F9B8\\U0001F3FD\\U0000200D\\U00002640|\\U0001F9B8\\U0001F3FE\\U0000200D\\U00002640|\\U0001F9B8\\U0001F3FF\\U0000200D\\U00002640|\\U0001F9B9\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9B9\\U0001F3FB\\U0000200D\\U00002642|\\U0001F9B9\\U0001F3FC\\U0000200D\\U00002642|\\U0001F9B9\\U0001F3FD\\U0000200D\\U00002642|\\U0001F9B9\\U0001F3FE\\U0000200D\\U00002642|\\U0001F9B9\\U0001F3FF\\U0000200D\\U00002642|\\U0001F9B9\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9B9\\U0001F3FB\\U0000200D\\U00002640|\\U0001F9B9\\U0001F3FC\\U0000200D\\U00002640|\\U0001F9B9\\U0001F3FD\\U0000200D\\U00002640|\\U0001F9B9\\U0001F3FE\\U0000200D\\U00002640|\\U0001F9B9\\U0001F3FF\\U0000200D\\U00002640|\\U0001F9D9\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D9\\U0001F3FB\\U0000200D\\U00002642|\\U0001F9D9\\U0001F3FC\\U0000200D\\U00002642|\\U0001F9D9\\U0001F3FD\\U0000200D\\U00002642|\\U0001F9D9\\U0001F3FE\\U0000200D\\U00002642|\\U0001F9D9\\U0001F3FF\\U0000200D\\U00002642|\\U0001F9D9\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D9\\U0001F3FB\\U0000200D\\U00002640|\\U0001F9D9\\U0001F3FC\\U0000200D\\U00002640|\\U0001F9D9\\U0001F3FD\\U0000200D\\U00002640|\\U0001F9D9\\U0001F3FE\\U0000200D\\U00002640|\\U0001F9D9\\U0001F3FF\\U0000200D\\U00002640|\\U0001F9DA\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DA\\U0001F3FB\\U0000200D\\U00002642|\\U0001F9DA\\U0001F3FC\\U0000200D\\U00002642|\\U0001F9DA\\U0001F3FD\\U0000200D\\U00002642|\\U0001F9DA\\U0001F3FE\\U0000200D\\U00002642|\\U0001F9DA\\U0001F3FF\\U0000200D\\U00002642|\\U0001F9DA\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DA\\U0001F3FB\\U0000200D\\U00002640|\\U0001F9DA\\U0001F3FC\\U0000200D\\U00002640|\\U0001F9DA\\U0001F3FD\\U0000200D\\U00002640|\\U0001F9DA\\U0001F3FE\\U0000200D\\U00002640|\\U0001F9DA\\U0001F3FF\\U0000200D\\U00002640|\\U0001F9DB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DB\\U0001F3FB\\U0000200D\\U00002642|\\U0001F9DB\\U0001F3FC\\U0000200D\\U00002642|\\U0001F9DB\\U0001F3FD\\U0000200D\\U00002642|\\U0001F9DB\\U0001F3FE\\U0000200D\\U00002642|\\U0001F9DB\\U0001F3FF\\U0000200D\\U00002642|\\U0001F9DB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DB\\U0001F3FB\\U0000200D\\U00002640|\\U0001F9DB\\U0001F3FC\\U0000200D\\U00002640|\\U0001F9DB\\U0001F3FD\\U0000200D\\U00002640|\\U0001F9DB\\U0001F3FE\\U0000200D\\U00002640|\\U0001F9DB\\U0001F3FF\\U0000200D\\U00002640|\\U0001F9DC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DC\\U0001F3FB\\U0000200D\\U00002642|\\U0001F9DC\\U0001F3FC\\U0000200D\\U00002642|\\U0001F9DC\\U0001F3FD\\U0000200D\\U00002642|\\U0001F9DC\\U0001F3FE\\U0000200D\\U00002642|\\U0001F9DC\\U0001F3FF\\U0000200D\\U00002642|\\U0001F9DC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DC\\U0001F3FB\\U0000200D\\U00002640|\\U0001F9DC\\U0001F3FC\\U0000200D\\U00002640|\\U0001F9DC\\U0001F3FD\\U0000200D\\U00002640|\\U0001F9DC\\U0001F3FE\\U0000200D\\U00002640|\\U0001F9DC\\U0001F3FF\\U0000200D\\U00002640|\\U0001F9DD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DD\\U0001F3FB\\U0000200D\\U00002642|\\U0001F9DD\\U0001F3FC\\U0000200D\\U00002642|\\U0001F9DD\\U0001F3FD\\U0000200D\\U00002642|\\U0001F9DD\\U0001F3FE\\U0000200D\\U00002642|\\U0001F9DD\\U0001F3FF\\U0000200D\\U00002642|\\U0001F9DD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DD\\U0001F3FB\\U0000200D\\U00002640|\\U0001F9DD\\U0001F3FC\\U0000200D\\U00002640|\\U0001F9DD\\U0001F3FD\\U0000200D\\U00002640|\\U0001F9DD\\U0001F3FE\\U0000200D\\U00002640|\\U0001F9DD\\U0001F3FF\\U0000200D\\U00002640|\\U0001F9DE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9DF\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9DF\\U0000200D\\U00002640\\U0000FE0F|\\U0001F486\\U0000200D\\U00002642\\U0000FE0F|\\U0001F486\\U0001F3FB\\U0000200D\\U00002642|\\U0001F486\\U0001F3FC\\U0000200D\\U00002642|\\U0001F486\\U0001F3FD\\U0000200D\\U00002642|\\U0001F486\\U0001F3FE\\U0000200D\\U00002642|\\U0001F486\\U0001F3FF\\U0000200D\\U00002642|\\U0001F486\\U0000200D\\U00002640\\U0000FE0F|\\U0001F486\\U0001F3FB\\U0000200D\\U00002640|\\U0001F486\\U0001F3FC\\U0000200D\\U00002640|\\U0001F486\\U0001F3FD\\U0000200D\\U00002640|\\U0001F486\\U0001F3FE\\U0000200D\\U00002640|\\U0001F486\\U0001F3FF\\U0000200D\\U00002640|\\U0001F487\\U0000200D\\U00002642\\U0000FE0F|\\U0001F487\\U0001F3FB\\U0000200D\\U00002642|\\U0001F487\\U0001F3FC\\U0000200D\\U00002642|\\U0001F487\\U0001F3FD\\U0000200D\\U00002642|\\U0001F487\\U0001F3FE\\U0000200D\\U00002642|\\U0001F487\\U0001F3FF\\U0000200D\\U00002642|\\U0001F487\\U0000200D\\U00002640\\U0000FE0F|\\U0001F487\\U0001F3FB\\U0000200D\\U00002640|\\U0001F487\\U0001F3FC\\U0000200D\\U00002640|\\U0001F487\\U0001F3FD\\U0000200D\\U00002640|\\U0001F487\\U0001F3FE\\U0000200D\\U00002640|\\U0001F487\\U0001F3FF\\U0000200D\\U00002640|\\U0001F6B6\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B6\\U0001F3FB\\U0000200D\\U00002642|\\U0001F6B6\\U0001F3FC\\U0000200D\\U00002642|\\U0001F6B6\\U0001F3FD\\U0000200D\\U00002642|\\U0001F6B6\\U0001F3FE\\U0000200D\\U00002642|\\U0001F6B6\\U0001F3FF\\U0000200D\\U00002642|\\U0001F6B6\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B6\\U0001F3FB\\U0000200D\\U00002640|\\U0001F6B6\\U0001F3FC\\U0000200D\\U00002640|\\U0001F6B6\\U0001F3FD\\U0000200D\\U00002640|\\U0001F6B6\\U0001F3FE\\U0000200D\\U00002640|\\U0001F6B6\\U0001F3FF\\U0000200D\\U00002640|\\U0001F6B6\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F6B6\\U0001F3FB\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FC\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FD\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FE\\U0000200D\\U000027A1|\\U0001F6B6\\U0001F3FF\\U0000200D\\U000027A1|\\U0001F9CD\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CD\\U0001F3FB\\U0000200D\\U00002642|\\U0001F9CD\\U0001F3FC\\U0000200D\\U00002642|\\U0001F9CD\\U0001F3FD\\U0000200D\\U00002642|\\U0001F9CD\\U0001F3FE\\U0000200D\\U00002642|\\U0001F9CD\\U0001F3FF\\U0000200D\\U00002642|\\U0001F9CD\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CD\\U0001F3FB\\U0000200D\\U00002640|\\U0001F9CD\\U0001F3FC\\U0000200D\\U00002640|\\U0001F9CD\\U0001F3FD\\U0000200D\\U00002640|\\U0001F9CD\\U0001F3FE\\U0000200D\\U00002640|\\U0001F9CD\\U0001F3FF\\U0000200D\\U00002640|\\U0001F9CE\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9CE\\U0001F3FB\\U0000200D\\U00002642|\\U0001F9CE\\U0001F3FC\\U0000200D\\U00002642|\\U0001F9CE\\U0001F3FD\\U0000200D\\U00002642|\\U0001F9CE\\U0001F3FE\\U0000200D\\U00002642|\\U0001F9CE\\U0001F3FF\\U0000200D\\U00002642|\\U0001F9CE\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9CE\\U0001F3FB\\U0000200D\\U00002640|\\U0001F9CE\\U0001F3FC\\U0000200D\\U00002640|\\U0001F9CE\\U0001F3FD\\U0000200D\\U00002640|\\U0001F9CE\\U0001F3FE\\U0000200D\\U00002640|\\U0001F9CE\\U0001F3FF\\U0000200D\\U00002640|\\U0001F9CE\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F9CE\\U0001F3FB\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FC\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FD\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FE\\U0000200D\\U000027A1|\\U0001F9CE\\U0001F3FF\\U0000200D\\U000027A1|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F9AF|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F9AF|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F9AF|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F9AF|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F9AF|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F9AF|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F9AF|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F9AF|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F9AF|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F9AF|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F9AF|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F9AF|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F9AF|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F9AF|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F9AF|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F9BC|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F9BC|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F9BC|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F9BC|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F9BC|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F9BC|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F9BC|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F9BC|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F9BC|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F9BC|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F9BC|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F9BC|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F9BC|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F9BC|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F9BC|\\U0001F9D1\\U0001F3FB\\U0000200D\\U0001F9BD|\\U0001F9D1\\U0001F3FC\\U0000200D\\U0001F9BD|\\U0001F9D1\\U0001F3FD\\U0000200D\\U0001F9BD|\\U0001F9D1\\U0001F3FE\\U0000200D\\U0001F9BD|\\U0001F9D1\\U0001F3FF\\U0000200D\\U0001F9BD|\\U0001F468\\U0001F3FB\\U0000200D\\U0001F9BD|\\U0001F468\\U0001F3FC\\U0000200D\\U0001F9BD|\\U0001F468\\U0001F3FD\\U0000200D\\U0001F9BD|\\U0001F468\\U0001F3FE\\U0000200D\\U0001F9BD|\\U0001F468\\U0001F3FF\\U0000200D\\U0001F9BD|\\U0001F469\\U0001F3FB\\U0000200D\\U0001F9BD|\\U0001F469\\U0001F3FC\\U0000200D\\U0001F9BD|\\U0001F469\\U0001F3FD\\U0000200D\\U0001F9BD|\\U0001F469\\U0001F3FE\\U0000200D\\U0001F9BD|\\U0001F469\\U0001F3FF\\U0000200D\\U0001F9BD|\\U0001F3C3\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3C3\\U0001F3FB\\U0000200D\\U00002642|\\U0001F3C3\\U0001F3FC\\U0000200D\\U00002642|\\U0001F3C3\\U0001F3FD\\U0000200D\\U00002642|\\U0001F3C3\\U0001F3FE\\U0000200D\\U00002642|\\U0001F3C3\\U0001F3FF\\U0000200D\\U00002642|\\U0001F3C3\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3C3\\U0001F3FB\\U0000200D\\U00002640|\\U0001F3C3\\U0001F3FC\\U0000200D\\U00002640|\\U0001F3C3\\U0001F3FD\\U0000200D\\U00002640|\\U0001F3C3\\U0001F3FE\\U0000200D\\U00002640|\\U0001F3C3\\U0001F3FF\\U0000200D\\U00002640|\\U0001F3C3\\U0000200D\\U000027A1\\U0000FE0F|\\U0001F3C3\\U0001F3FB\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FC\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FD\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FE\\U0000200D\\U000027A1|\\U0001F3C3\\U0001F3FF\\U0000200D\\U000027A1|\\U0001F46F\\U0000200D\\U00002642\\U0000FE0F|\\U0001F46F\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D6\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D6\\U0001F3FB\\U0000200D\\U00002642|\\U0001F9D6\\U0001F3FC\\U0000200D\\U00002642|\\U0001F9D6\\U0001F3FD\\U0000200D\\U00002642|\\U0001F9D6\\U0001F3FE\\U0000200D\\U00002642|\\U0001F9D6\\U0001F3FF\\U0000200D\\U00002642|\\U0001F9D6\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D6\\U0001F3FB\\U0000200D\\U00002640|\\U0001F9D6\\U0001F3FC\\U0000200D\\U00002640|\\U0001F9D6\\U0001F3FD\\U0000200D\\U00002640|\\U0001F9D6\\U0001F3FE\\U0000200D\\U00002640|\\U0001F9D6\\U0001F3FF\\U0000200D\\U00002640|\\U0001F9D7\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D7\\U0001F3FB\\U0000200D\\U00002642|\\U0001F9D7\\U0001F3FC\\U0000200D\\U00002642|\\U0001F9D7\\U0001F3FD\\U0000200D\\U00002642|\\U0001F9D7\\U0001F3FE\\U0000200D\\U00002642|\\U0001F9D7\\U0001F3FF\\U0000200D\\U00002642|\\U0001F9D7\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D7\\U0001F3FB\\U0000200D\\U00002640|\\U0001F9D7\\U0001F3FC\\U0000200D\\U00002640|\\U0001F9D7\\U0001F3FD\\U0000200D\\U00002640|\\U0001F9D7\\U0001F3FE\\U0000200D\\U00002640|\\U0001F9D7\\U0001F3FF\\U0000200D\\U00002640|\\U0001F3CC\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CC\\U0000FE0F\\U0000200D\\U00002642|\\U0001F3CC\\U0001F3FB\\U0000200D\\U00002642|\\U0001F3CC\\U0001F3FC\\U0000200D\\U00002642|\\U0001F3CC\\U0001F3FD\\U0000200D\\U00002642|\\U0001F3CC\\U0001F3FE\\U0000200D\\U00002642|\\U0001F3CC\\U0001F3FF\\U0000200D\\U00002642|\\U0001F3CC\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CC\\U0000FE0F\\U0000200D\\U00002640|\\U0001F3CC\\U0001F3FB\\U0000200D\\U00002640|\\U0001F3CC\\U0001F3FC\\U0000200D\\U00002640|\\U0001F3CC\\U0001F3FD\\U0000200D\\U00002640|\\U0001F3CC\\U0001F3FE\\U0000200D\\U00002640|\\U0001F3CC\\U0001F3FF\\U0000200D\\U00002640|\\U0001F3C4\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3C4\\U0001F3FB\\U0000200D\\U00002642|\\U0001F3C4\\U0001F3FC\\U0000200D\\U00002642|\\U0001F3C4\\U0001F3FD\\U0000200D\\U00002642|\\U0001F3C4\\U0001F3FE\\U0000200D\\U00002642|\\U0001F3C4\\U0001F3FF\\U0000200D\\U00002642|\\U0001F3C4\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3C4\\U0001F3FB\\U0000200D\\U00002640|\\U0001F3C4\\U0001F3FC\\U0000200D\\U00002640|\\U0001F3C4\\U0001F3FD\\U0000200D\\U00002640|\\U0001F3C4\\U0001F3FE\\U0000200D\\U00002640|\\U0001F3C4\\U0001F3FF\\U0000200D\\U00002640|\\U0001F6A3\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6A3\\U0001F3FB\\U0000200D\\U00002642|\\U0001F6A3\\U0001F3FC\\U0000200D\\U00002642|\\U0001F6A3\\U0001F3FD\\U0000200D\\U00002642|\\U0001F6A3\\U0001F3FE\\U0000200D\\U00002642|\\U0001F6A3\\U0001F3FF\\U0000200D\\U00002642|\\U0001F6A3\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6A3\\U0001F3FB\\U0000200D\\U00002640|\\U0001F6A3\\U0001F3FC\\U0000200D\\U00002640|\\U0001F6A3\\U0001F3FD\\U0000200D\\U00002640|\\U0001F6A3\\U0001F3FE\\U0000200D\\U00002640|\\U0001F6A3\\U0001F3FF\\U0000200D\\U00002640|\\U0001F3CA\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CA\\U0001F3FB\\U0000200D\\U00002642|\\U0001F3CA\\U0001F3FC\\U0000200D\\U00002642|\\U0001F3CA\\U0001F3FD\\U0000200D\\U00002642|\\U0001F3CA\\U0001F3FE\\U0000200D\\U00002642|\\U0001F3CA\\U0001F3FF\\U0000200D\\U00002642|\\U0001F3CA\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CA\\U0001F3FB\\U0000200D\\U00002640|\\U0001F3CA\\U0001F3FC\\U0000200D\\U00002640|\\U0001F3CA\\U0001F3FD\\U0000200D\\U00002640|\\U0001F3CA\\U0001F3FE\\U0000200D\\U00002640|\\U0001F3CA\\U0001F3FF\\U0000200D\\U00002640|\\U000026F9\\U0000200D\\U00002642\\U0000FE0F|\\U000026F9\\U0000FE0F\\U0000200D\\U00002642|\\U000026F9\\U0001F3FB\\U0000200D\\U00002642|\\U000026F9\\U0001F3FC\\U0000200D\\U00002642|\\U000026F9\\U0001F3FD\\U0000200D\\U00002642|\\U000026F9\\U0001F3FE\\U0000200D\\U00002642|\\U000026F9\\U0001F3FF\\U0000200D\\U00002642|\\U000026F9\\U0000200D\\U00002640\\U0000FE0F|\\U000026F9\\U0000FE0F\\U0000200D\\U00002640|\\U000026F9\\U0001F3FB\\U0000200D\\U00002640|\\U000026F9\\U0001F3FC\\U0000200D\\U00002640|\\U000026F9\\U0001F3FD\\U0000200D\\U00002640|\\U000026F9\\U0001F3FE\\U0000200D\\U00002640|\\U000026F9\\U0001F3FF\\U0000200D\\U00002640|\\U0001F3CB\\U0000200D\\U00002642\\U0000FE0F|\\U0001F3CB\\U0000FE0F\\U0000200D\\U00002642|\\U0001F3CB\\U0001F3FB\\U0000200D\\U00002642|\\U0001F3CB\\U0001F3FC\\U0000200D\\U00002642|\\U0001F3CB\\U0001F3FD\\U0000200D\\U00002642|\\U0001F3CB\\U0001F3FE\\U0000200D\\U00002642|\\U0001F3CB\\U0001F3FF\\U0000200D\\U00002642|\\U0001F3CB\\U0000200D\\U00002640\\U0000FE0F|\\U0001F3CB\\U0000FE0F\\U0000200D\\U00002640|\\U0001F3CB\\U0001F3FB\\U0000200D\\U00002640|\\U0001F3CB\\U0001F3FC\\U0000200D\\U00002640|\\U0001F3CB\\U0001F3FD\\U0000200D\\U00002640|\\U0001F3CB\\U0001F3FE\\U0000200D\\U00002640|\\U0001F3CB\\U0001F3FF\\U0000200D\\U00002640|\\U0001F6B4\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B4\\U0001F3FB\\U0000200D\\U00002642|\\U0001F6B4\\U0001F3FC\\U0000200D\\U00002642|\\U0001F6B4\\U0001F3FD\\U0000200D\\U00002642|\\U0001F6B4\\U0001F3FE\\U0000200D\\U00002642|\\U0001F6B4\\U0001F3FF\\U0000200D\\U00002642|\\U0001F6B4\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B4\\U0001F3FB\\U0000200D\\U00002640|\\U0001F6B4\\U0001F3FC\\U0000200D\\U00002640|\\U0001F6B4\\U0001F3FD\\U0000200D\\U00002640|\\U0001F6B4\\U0001F3FE\\U0000200D\\U00002640|\\U0001F6B4\\U0001F3FF\\U0000200D\\U00002640|\\U0001F6B5\\U0000200D\\U00002642\\U0000FE0F|\\U0001F6B5\\U0001F3FB\\U0000200D\\U00002642|\\U0001F6B5\\U0001F3FC\\U0000200D\\U00002642|\\U0001F6B5\\U0001F3FD\\U0000200D\\U00002642|\\U0001F6B5\\U0001F3FE\\U0000200D\\U00002642|\\U0001F6B5\\U0001F3FF\\U0000200D\\U00002642|\\U0001F6B5\\U0000200D\\U00002640\\U0000FE0F|\\U0001F6B5\\U0001F3FB\\U0000200D\\U00002640|\\U0001F6B5\\U0001F3FC\\U0000200D\\U00002640|\\U0001F6B5\\U0001F3FD\\U0000200D\\U00002640|\\U0001F6B5\\U0001F3FE\\U0000200D\\U00002640|\\U0001F6B5\\U0001F3FF\\U0000200D\\U00002640|\\U0001F938\\U0000200D\\U00002642\\U0000FE0F|\\U0001F938\\U0001F3FB\\U0000200D\\U00002642|\\U0001F938\\U0001F3FC\\U0000200D\\U00002642|\\U0001F938\\U0001F3FD\\U0000200D\\U00002642|\\U0001F938\\U0001F3FE\\U0000200D\\U00002642|\\U0001F938\\U0001F3FF\\U0000200D\\U00002642|\\U0001F938\\U0000200D\\U00002640\\U0000FE0F|\\U0001F938\\U0001F3FB\\U0000200D\\U00002640|\\U0001F938\\U0001F3FC\\U0000200D\\U00002640|\\U0001F938\\U0001F3FD\\U0000200D\\U00002640|\\U0001F938\\U0001F3FE\\U0000200D\\U00002640|\\U0001F938\\U0001F3FF\\U0000200D\\U00002640|\\U0001F93C\\U0000200D\\U00002642\\U0000FE0F|\\U0001F93C\\U0000200D\\U00002640\\U0000FE0F|\\U0001F93D\\U0000200D\\U00002642\\U0000FE0F|\\U0001F93D\\U0001F3FB\\U0000200D\\U00002642|\\U0001F93D\\U0001F3FC\\U0000200D\\U00002642|\\U0001F93D\\U0001F3FD\\U0000200D\\U00002642|\\U0001F93D\\U0001F3FE\\U0000200D\\U00002642|\\U0001F93D\\U0001F3FF\\U0000200D\\U00002642|\\U0001F93D\\U0000200D\\U00002640\\U0000FE0F|\\U0001F93D\\U0001F3FB\\U0000200D\\U00002640|\\U0001F93D\\U0001F3FC\\U0000200D\\U00002640|\\U0001F93D\\U0001F3FD\\U0000200D\\U00002640|\\U0001F93D\\U0001F3FE\\U0000200D\\U00002640|\\U0001F93D\\U0001F3FF\\U0000200D\\U00002640|\\U0001F93E\\U0000200D\\U00002642\\U0000FE0F|\\U0001F93E\\U0001F3FB\\U0000200D\\U00002642|\\U0001F93E\\U0001F3FC\\U0000200D\\U00002642|\\U0001F93E\\U0001F3FD\\U0000200D\\U00002642|\\U0001F93E\\U0001F3FE\\U0000200D\\U00002642|\\U0001F93E\\U0001F3FF\\U0000200D\\U00002642|\\U0001F93E\\U0000200D\\U00002640\\U0000FE0F|\\U0001F93E\\U0001F3FB\\U0000200D\\U00002640|\\U0001F93E\\U0001F3FC\\U0000200D\\U00002640|\\U0001F93E\\U0001F3FD\\U0000200D\\U00002640|\\U0001F93E\\U0001F3FE\\U0000200D\\U00002640|\\U0001F93E\\U0001F3FF\\U0000200D\\U00002640|\\U0001F939\\U0000200D\\U00002642\\U0000FE0F|\\U0001F939\\U0001F3FB\\U0000200D\\U00002642|\\U0001F939\\U0001F3FC\\U0000200D\\U00002642|\\U0001F939\\U0001F3FD\\U0000200D\\U00002642|\\U0001F939\\U0001F3FE\\U0000200D\\U00002642|\\U0001F939\\U0001F3FF\\U0000200D\\U00002642|\\U0001F939\\U0000200D\\U00002640\\U0000FE0F|\\U0001F939\\U0001F3FB\\U0000200D\\U00002640|\\U0001F939\\U0001F3FC\\U0000200D\\U00002640|\\U0001F939\\U0001F3FD\\U0000200D\\U00002640|\\U0001F939\\U0001F3FE\\U0000200D\\U00002640|\\U0001F939\\U0001F3FF\\U0000200D\\U00002640|\\U0001F9D8\\U0000200D\\U00002642\\U0000FE0F|\\U0001F9D8\\U0001F3FB\\U0000200D\\U00002642|\\U0001F9D8\\U0001F3FC\\U0000200D\\U00002642|\\U0001F9D8\\U0001F3FD\\U0000200D\\U00002642|\\U0001F9D8\\U0001F3FE\\U0000200D\\U00002642|\\U0001F9D8\\U0001F3FF\\U0000200D\\U00002642|\\U0001F9D8\\U0000200D\\U00002640\\U0000FE0F|\\U0001F9D8\\U0001F3FB\\U0000200D\\U00002640|\\U0001F9D8\\U0001F3FC\\U0000200D\\U00002640|\\U0001F9D8\\U0001F3FD\\U0000200D\\U00002640|\\U0001F9D8\\U0001F3FE\\U0000200D\\U00002640|\\U0001F9D8\\U0001F3FF\\U0000200D\\U00002640|\\U0001F43B\\U0000200D\\U00002744\\U0000FE0F|\\U000026D3\\U0000FE0F\\U0000200D\\U0001F4A5|\\U0001F3F3\\U0000FE0F\\U0000200D\\U0001F308|\\U0001F3F3\\U0000200D\\U000026A7\\U0000FE0F|\\U0001F3F3\\U0000FE0F\\U0000200D\\U000026A7|\\U0001F3F4\\U0000200D\\U00002620\\U0000FE0F|\\U0001F636\\U0000200D\\U0001F32B|\\U0001F62E\\U0000200D\\U0001F4A8|\\U0001F642\\U0000200D\\U00002194|\\U0001F642\\U0000200D\\U00002195|\\U0001F635\\U0000200D\\U0001F4AB|\\U00002764\\U0000200D\\U0001F525|\\U00002764\\U0000200D\\U0001FA79|\\U0001F441\\U0000200D\\U0001F5E8|\\U0001F9D4\\U0000200D\\U00002642|\\U0001F9D4\\U0000200D\\U00002640|\\U0001F468\\U0000200D\\U0001F9B0|\\U0001F468\\U0000200D\\U0001F9B1|\\U0001F468\\U0000200D\\U0001F9B3|\\U0001F468\\U0000200D\\U0001F9B2|\\U0001F469\\U0000200D\\U0001F9B0|\\U0001F9D1\\U0000200D\\U0001F9B0|\\U0001F469\\U0000200D\\U0001F9B1|\\U0001F9D1\\U0000200D\\U0001F9B1|\\U0001F469\\U0000200D\\U0001F9B3|\\U0001F9D1\\U0000200D\\U0001F9B3|\\U0001F469\\U0000200D\\U0001F9B2|\\U0001F9D1\\U0000200D\\U0001F9B2|\\U0001F471\\U0000200D\\U00002640|\\U0001F471\\U0000200D\\U00002642|\\U0001F64D\\U0000200D\\U00002642|\\U0001F64D\\U0000200D\\U00002640|\\U0001F64E\\U0000200D\\U00002642|\\U0001F64E\\U0000200D\\U00002640|\\U0001F645\\U0000200D\\U00002642|\\U0001F645\\U0000200D\\U00002640|\\U0001F646\\U0000200D\\U00002642|\\U0001F646\\U0000200D\\U00002640|\\U0001F481\\U0000200D\\U00002642|\\U0001F481\\U0000200D\\U00002640|\\U0001F64B\\U0000200D\\U00002642|\\U0001F64B\\U0000200D\\U00002640|\\U0001F9CF\\U0000200D\\U00002642|\\U0001F9CF\\U0000200D\\U00002640|\\U0001F647\\U0000200D\\U00002642|\\U0001F647\\U0000200D\\U00002640|\\U0001F926\\U0000200D\\U00002642|\\U0001F926\\U0000200D\\U00002640|\\U0001F937\\U0000200D\\U00002642|\\U0001F937\\U0000200D\\U00002640|\\U0001F9D1\\U0000200D\\U00002695|\\U0001F468\\U0000200D\\U00002695|\\U0001F469\\U0000200D\\U00002695|\\U0001F9D1\\U0000200D\\U0001F393|\\U0001F468\\U0000200D\\U0001F393|\\U0001F469\\U0000200D\\U0001F393|\\U0001F9D1\\U0000200D\\U0001F3EB|\\U0001F468\\U0000200D\\U0001F3EB|\\U0001F469\\U0000200D\\U0001F3EB|\\U0001F9D1\\U0000200D\\U00002696|\\U0001F468\\U0000200D\\U00002696|\\U0001F469\\U0000200D\\U00002696|\\U0001F9D1\\U0000200D\\U0001F33E|\\U0001F468\\U0000200D\\U0001F33E|\\U0001F469\\U0000200D\\U0001F33E|\\U0001F9D1\\U0000200D\\U0001F373|\\U0001F468\\U0000200D\\U0001F373|\\U0001F469\\U0000200D\\U0001F373|\\U0001F9D1\\U0000200D\\U0001F527|\\U0001F468\\U0000200D\\U0001F527|\\U0001F469\\U0000200D\\U0001F527|\\U0001F9D1\\U0000200D\\U0001F3ED|\\U0001F468\\U0000200D\\U0001F3ED|\\U0001F469\\U0000200D\\U0001F3ED|\\U0001F9D1\\U0000200D\\U0001F4BC|\\U0001F468\\U0000200D\\U0001F4BC|\\U0001F469\\U0000200D\\U0001F4BC|\\U0001F9D1\\U0000200D\\U0001F52C|\\U0001F468\\U0000200D\\U0001F52C|\\U0001F469\\U0000200D\\U0001F52C|\\U0001F9D1\\U0000200D\\U0001F4BB|\\U0001F468\\U0000200D\\U0001F4BB|\\U0001F469\\U0000200D\\U0001F4BB|\\U0001F9D1\\U0000200D\\U0001F3A4|\\U0001F468\\U0000200D\\U0001F3A4|\\U0001F469\\U0000200D\\U0001F3A4|\\U0001F9D1\\U0000200D\\U0001F3A8|\\U0001F468\\U0000200D\\U0001F3A8|\\U0001F469\\U0000200D\\U0001F3A8|\\U0001F9D1\\U0000200D\\U00002708|\\U0001F468\\U0000200D\\U00002708|\\U0001F469\\U0000200D\\U00002708|\\U0001F9D1\\U0000200D\\U0001F680|\\U0001F468\\U0000200D\\U0001F680|\\U0001F469\\U0000200D\\U0001F680|\\U0001F9D1\\U0000200D\\U0001F692|\\U0001F468\\U0000200D\\U0001F692|\\U0001F469\\U0000200D\\U0001F692|\\U0001F46E\\U0000200D\\U00002642|\\U0001F46E\\U0000200D\\U00002640|\\U0001F575\\U0000200D\\U00002642|\\U0001F575\\U0000200D\\U00002640|\\U0001F482\\U0000200D\\U00002642|\\U0001F482\\U0000200D\\U00002640|\\U0001F477\\U0000200D\\U00002642|\\U0001F477\\U0000200D\\U00002640|\\U0001F473\\U0000200D\\U00002642|\\U0001F473\\U0000200D\\U00002640|\\U0001F935\\U0000200D\\U00002642|\\U0001F935\\U0000200D\\U00002640|\\U0001F470\\U0000200D\\U00002642|\\U0001F470\\U0000200D\\U00002640|\\U0001F469\\U0000200D\\U0001F37C|\\U0001F468\\U0000200D\\U0001F37C|\\U0001F9D1\\U0000200D\\U0001F37C|\\U0001F9D1\\U0000200D\\U0001F384|\\U0001F9B8\\U0000200D\\U00002642|\\U0001F9B8\\U0000200D\\U00002640|\\U0001F9B9\\U0000200D\\U00002642|\\U0001F9B9\\U0000200D\\U00002640|\\U0001F9D9\\U0000200D\\U00002642|\\U0001F9D9\\U0000200D\\U00002640|\\U0001F9DA\\U0000200D\\U00002642|\\U0001F9DA\\U0000200D\\U00002640|\\U0001F9DB\\U0000200D\\U00002642|\\U0001F9DB\\U0000200D\\U00002640|\\U0001F9DC\\U0000200D\\U00002642|\\U0001F9DC\\U0000200D\\U00002640|\\U0001F9DD\\U0000200D\\U00002642|\\U0001F9DD\\U0000200D\\U00002640|\\U0001F9DE\\U0000200D\\U00002642|\\U0001F9DE\\U0000200D\\U00002640|\\U0001F9DF\\U0000200D\\U00002642|\\U0001F9DF\\U0000200D\\U00002640|\\U0001F486\\U0000200D\\U00002642|\\U0001F486\\U0000200D\\U00002640|\\U0001F487\\U0000200D\\U00002642|\\U0001F487\\U0000200D\\U00002640|\\U0001F6B6\\U0000200D\\U00002642|\\U0001F6B6\\U0000200D\\U00002640|\\U0001F6B6\\U0000200D\\U000027A1|\\U0001F9CD\\U0000200D\\U00002642|\\U0001F9CD\\U0000200D\\U00002640|\\U0001F9CE\\U0000200D\\U00002642|\\U0001F9CE\\U0000200D\\U00002640|\\U0001F9CE\\U0000200D\\U000027A1|\\U0001F9D1\\U0000200D\\U0001F9AF|\\U0001F468\\U0000200D\\U0001F9AF|\\U0001F469\\U0000200D\\U0001F9AF|\\U0001F9D1\\U0000200D\\U0001F9BC|\\U0001F468\\U0000200D\\U0001F9BC|\\U0001F469\\U0000200D\\U0001F9BC|\\U0001F9D1\\U0000200D\\U0001F9BD|\\U0001F468\\U0000200D\\U0001F9BD|\\U0001F469\\U0000200D\\U0001F9BD|\\U0001F3C3\\U0000200D\\U00002642|\\U0001F3C3\\U0000200D\\U00002640|\\U0001F3C3\\U0000200D\\U000027A1|\\U0001F46F\\U0000200D\\U00002642|\\U0001F46F\\U0000200D\\U00002640|\\U0001F9D6\\U0000200D\\U00002642|\\U0001F9D6\\U0000200D\\U00002640|\\U0001F9D7\\U0000200D\\U00002642|\\U0001F9D7\\U0000200D\\U00002640|\\U0001F3CC\\U0000200D\\U00002642|\\U0001F3CC\\U0000200D\\U00002640|\\U0001F3C4\\U0000200D\\U00002642|\\U0001F3C4\\U0000200D\\U00002640|\\U0001F6A3\\U0000200D\\U00002642|\\U0001F6A3\\U0000200D\\U00002640|\\U0001F3CA\\U0000200D\\U00002642|\\U0001F3CA\\U0000200D\\U00002640|\\U000026F9\\U0000200D\\U00002642|\\U000026F9\\U0000200D\\U00002640|\\U0001F3CB\\U0000200D\\U00002642|\\U0001F3CB\\U0000200D\\U00002640|\\U0001F6B4\\U0000200D\\U00002642|\\U0001F6B4\\U0000200D\\U00002640|\\U0001F6B5\\U0000200D\\U00002642|\\U0001F6B5\\U0000200D\\U00002640|\\U0001F938\\U0000200D\\U00002642|\\U0001F938\\U0000200D\\U00002640|\\U0001F93C\\U0000200D\\U00002642|\\U0001F93C\\U0000200D\\U00002640|\\U0001F93D\\U0000200D\\U00002642|\\U0001F93D\\U0000200D\\U00002640|\\U0001F93E\\U0000200D\\U00002642|\\U0001F93E\\U0000200D\\U00002640|\\U0001F939\\U0000200D\\U00002642|\\U0001F939\\U0000200D\\U00002640|\\U0001F9D8\\U0000200D\\U00002642|\\U0001F9D8\\U0000200D\\U00002640|\\U0001F468\\U0000200D\\U0001F466|\\U0001F468\\U0000200D\\U0001F467|\\U0001F469\\U0000200D\\U0001F466|\\U0001F469\\U0000200D\\U0001F467|\\U0001F9D1\\U0000200D\\U0001F9D2|\\U0001F415\\U0000200D\\U0001F9BA|\\U0001F408\\U0000200D\\U00002B1B|\\U0001F43B\\U0000200D\\U00002744|\\U0001F426\\U0000200D\\U00002B1B|\\U0001F426\\U0000200D\\U0001F525|\\U0001F34B\\U0000200D\\U0001F7E9|\\U0001F344\\U0000200D\\U0001F7EB|\\U000026D3\\U0000200D\\U0001F4A5|\\U00000023\\U0000FE0F\\U000020E3|\\U0000002A\\U0000FE0F\\U000020E3|\\U00000030\\U0000FE0F\\U000020E3|\\U00000031\\U0000FE0F\\U000020E3|\\U00000032\\U0000FE0F\\U000020E3|\\U00000033\\U0000FE0F\\U000020E3|\\U00000034\\U0000FE0F\\U000020E3|\\U00000035\\U0000FE0F\\U000020E3|\\U00000036\\U0000FE0F\\U000020E3|\\U00000037\\U0000FE0F\\U000020E3|\\U00000038\\U0000FE0F\\U000020E3|\\U00000039\\U0000FE0F\\U000020E3|\\U0001F3F3\\U0000200D\\U0001F308|\\U0001F3F3\\U0000200D\\U000026A7|\\U0001F3F4\\U0000200D\\U00002620|\\U0000263A\\U0000FE0F|\\U00002639\\U0000FE0F|\\U00002620\\U0000FE0F|\\U00002763\\U0000FE0F|\\U00002764\\U0000FE0F|\\U0001F573\\U0000FE0F|\\U0001F5E8\\U0000FE0F|\\U0001F5EF\\U0000FE0F|\\U0001F44B\\U0001F3FB|\\U0001F44B\\U0001F3FC|\\U0001F44B\\U0001F3FD|\\U0001F44B\\U0001F3FE|\\U0001F44B\\U0001F3FF|\\U0001F91A\\U0001F3FB|\\U0001F91A\\U0001F3FC|\\U0001F91A\\U0001F3FD|\\U0001F91A\\U0001F3FE|\\U0001F91A\\U0001F3FF|\\U0001F590\\U0000FE0F|\\U0001F590\\U0001F3FB|\\U0001F590\\U0001F3FC|\\U0001F590\\U0001F3FD|\\U0001F590\\U0001F3FE|\\U0001F590\\U0001F3FF|\\U0000270B\\U0001F3FB|\\U0000270B\\U0001F3FC|\\U0000270B\\U0001F3FD|\\U0000270B\\U0001F3FE|\\U0000270B\\U0001F3FF|\\U0001F596\\U0001F3FB|\\U0001F596\\U0001F3FC|\\U0001F596\\U0001F3FD|\\U0001F596\\U0001F3FE|\\U0001F596\\U0001F3FF|\\U0001FAF1\\U0001F3FB|\\U0001FAF1\\U0001F3FC|\\U0001FAF1\\U0001F3FD|\\U0001FAF1\\U0001F3FE|\\U0001FAF1\\U0001F3FF|\\U0001FAF2\\U0001F3FB|\\U0001FAF2\\U0001F3FC|\\U0001FAF2\\U0001F3FD|\\U0001FAF2\\U0001F3FE|\\U0001FAF2\\U0001F3FF|\\U0001FAF3\\U0001F3FB|\\U0001FAF3\\U0001F3FC|\\U0001FAF3\\U0001F3FD|\\U0001FAF3\\U0001F3FE|\\U0001FAF3\\U0001F3FF|\\U0001FAF4\\U0001F3FB|\\U0001FAF4\\U0001F3FC|\\U0001FAF4\\U0001F3FD|\\U0001FAF4\\U0001F3FE|\\U0001FAF4\\U0001F3FF|\\U0001FAF7\\U0001F3FB|\\U0001FAF7\\U0001F3FC|\\U0001FAF7\\U0001F3FD|\\U0001FAF7\\U0001F3FE|\\U0001FAF7\\U0001F3FF|\\U0001FAF8\\U0001F3FB|\\U0001FAF8\\U0001F3FC|\\U0001FAF8\\U0001F3FD|\\U0001FAF8\\U0001F3FE|\\U0001FAF8\\U0001F3FF|\\U0001F44C\\U0001F3FB|\\U0001F44C\\U0001F3FC|\\U0001F44C\\U0001F3FD|\\U0001F44C\\U0001F3FE|\\U0001F44C\\U0001F3FF|\\U0001F90C\\U0001F3FB|\\U0001F90C\\U0001F3FC|\\U0001F90C\\U0001F3FD|\\U0001F90C\\U0001F3FE|\\U0001F90C\\U0001F3FF|\\U0001F90F\\U0001F3FB|\\U0001F90F\\U0001F3FC|\\U0001F90F\\U0001F3FD|\\U0001F90F\\U0001F3FE|\\U0001F90F\\U0001F3FF|\\U0000270C\\U0000FE0F|\\U0000270C\\U0001F3FB|\\U0000270C\\U0001F3FC|\\U0000270C\\U0001F3FD|\\U0000270C\\U0001F3FE|\\U0000270C\\U0001F3FF|\\U0001F91E\\U0001F3FB|\\U0001F91E\\U0001F3FC|\\U0001F91E\\U0001F3FD|\\U0001F91E\\U0001F3FE|\\U0001F91E\\U0001F3FF|\\U0001FAF0\\U0001F3FB|\\U0001FAF0\\U0001F3FC|\\U0001FAF0\\U0001F3FD|\\U0001FAF0\\U0001F3FE|\\U0001FAF0\\U0001F3FF|\\U0001F91F\\U0001F3FB|\\U0001F91F\\U0001F3FC|\\U0001F91F\\U0001F3FD|\\U0001F91F\\U0001F3FE|\\U0001F91F\\U0001F3FF|\\U0001F918\\U0001F3FB|\\U0001F918\\U0001F3FC|\\U0001F918\\U0001F3FD|\\U0001F918\\U0001F3FE|\\U0001F918\\U0001F3FF|\\U0001F919\\U0001F3FB|\\U0001F919\\U0001F3FC|\\U0001F919\\U0001F3FD|\\U0001F919\\U0001F3FE|\\U0001F919\\U0001F3FF|\\U0001F448\\U0001F3FB|\\U0001F448\\U0001F3FC|\\U0001F448\\U0001F3FD|\\U0001F448\\U0001F3FE|\\U0001F448\\U0001F3FF|\\U0001F449\\U0001F3FB|\\U0001F449\\U0001F3FC|\\U0001F449\\U0001F3FD|\\U0001F449\\U0001F3FE|\\U0001F449\\U0001F3FF|\\U0001F446\\U0001F3FB|\\U0001F446\\U0001F3FC|\\U0001F446\\U0001F3FD|\\U0001F446\\U0001F3FE|\\U0001F446\\U0001F3FF|\\U0001F595\\U0001F3FB|\\U0001F595\\U0001F3FC|\\U0001F595\\U0001F3FD|\\U0001F595\\U0001F3FE|\\U0001F595\\U0001F3FF|\\U0001F447\\U0001F3FB|\\U0001F447\\U0001F3FC|\\U0001F447\\U0001F3FD|\\U0001F447\\U0001F3FE|\\U0001F447\\U0001F3FF|\\U0000261D\\U0000FE0F|\\U0000261D\\U0001F3FB|\\U0000261D\\U0001F3FC|\\U0000261D\\U0001F3FD|\\U0000261D\\U0001F3FE|\\U0000261D\\U0001F3FF|\\U0001FAF5\\U0001F3FB|\\U0001FAF5\\U0001F3FC|\\U0001FAF5\\U0001F3FD|\\U0001FAF5\\U0001F3FE|\\U0001FAF5\\U0001F3FF|\\U0001F44D\\U0001F3FB|\\U0001F44D\\U0001F3FC|\\U0001F44D\\U0001F3FD|\\U0001F44D\\U0001F3FE|\\U0001F44D\\U0001F3FF|\\U0001F44E\\U0001F3FB|\\U0001F44E\\U0001F3FC|\\U0001F44E\\U0001F3FD|\\U0001F44E\\U0001F3FE|\\U0001F44E\\U0001F3FF|\\U0000270A\\U0001F3FB|\\U0000270A\\U0001F3FC|\\U0000270A\\U0001F3FD|\\U0000270A\\U0001F3FE|\\U0000270A\\U0001F3FF|\\U0001F44A\\U0001F3FB|\\U0001F44A\\U0001F3FC|\\U0001F44A\\U0001F3FD|\\U0001F44A\\U0001F3FE|\\U0001F44A\\U0001F3FF|\\U0001F91B\\U0001F3FB|\\U0001F91B\\U0001F3FC|\\U0001F91B\\U0001F3FD|\\U0001F91B\\U0001F3FE|\\U0001F91B\\U0001F3FF|\\U0001F91C\\U0001F3FB|\\U0001F91C\\U0001F3FC|\\U0001F91C\\U0001F3FD|\\U0001F91C\\U0001F3FE|\\U0001F91C\\U0001F3FF|\\U0001F44F\\U0001F3FB|\\U0001F44F\\U0001F3FC|\\U0001F44F\\U0001F3FD|\\U0001F44F\\U0001F3FE|\\U0001F44F\\U0001F3FF|\\U0001F64C\\U0001F3FB|\\U0001F64C\\U0001F3FC|\\U0001F64C\\U0001F3FD|\\U0001F64C\\U0001F3FE|\\U0001F64C\\U0001F3FF|\\U0001FAF6\\U0001F3FB|\\U0001FAF6\\U0001F3FC|\\U0001FAF6\\U0001F3FD|\\U0001FAF6\\U0001F3FE|\\U0001FAF6\\U0001F3FF|\\U0001F450\\U0001F3FB|\\U0001F450\\U0001F3FC|\\U0001F450\\U0001F3FD|\\U0001F450\\U0001F3FE|\\U0001F450\\U0001F3FF|\\U0001F932\\U0001F3FB|\\U0001F932\\U0001F3FC|\\U0001F932\\U0001F3FD|\\U0001F932\\U0001F3FE|\\U0001F932\\U0001F3FF|\\U0001F91D\\U0001F3FB|\\U0001F91D\\U0001F3FC|\\U0001F91D\\U0001F3FD|\\U0001F91D\\U0001F3FE|\\U0001F91D\\U0001F3FF|\\U0001F64F\\U0001F3FB|\\U0001F64F\\U0001F3FC|\\U0001F64F\\U0001F3FD|\\U0001F64F\\U0001F3FE|\\U0001F64F\\U0001F3FF|\\U0000270D\\U0000FE0F|\\U0000270D\\U0001F3FB|\\U0000270D\\U0001F3FC|\\U0000270D\\U0001F3FD|\\U0000270D\\U0001F3FE|\\U0000270D\\U0001F3FF|\\U0001F485\\U0001F3FB|\\U0001F485\\U0001F3FC|\\U0001F485\\U0001F3FD|\\U0001F485\\U0001F3FE|\\U0001F485\\U0001F3FF|\\U0001F933\\U0001F3FB|\\U0001F933\\U0001F3FC|\\U0001F933\\U0001F3FD|\\U0001F933\\U0001F3FE|\\U0001F933\\U0001F3FF|\\U0001F4AA\\U0001F3FB|\\U0001F4AA\\U0001F3FC|\\U0001F4AA\\U0001F3FD|\\U0001F4AA\\U0001F3FE|\\U0001F4AA\\U0001F3FF|\\U0001F9B5\\U0001F3FB|\\U0001F9B5\\U0001F3FC|\\U0001F9B5\\U0001F3FD|\\U0001F9B5\\U0001F3FE|\\U0001F9B5\\U0001F3FF|\\U0001F9B6\\U0001F3FB|\\U0001F9B6\\U0001F3FC|\\U0001F9B6\\U0001F3FD|\\U0001F9B6\\U0001F3FE|\\U0001F9B6\\U0001F3FF|\\U0001F442\\U0001F3FB|\\U0001F442\\U0001F3FC|\\U0001F442\\U0001F3FD|\\U0001F442\\U0001F3FE|\\U0001F442\\U0001F3FF|\\U0001F9BB\\U0001F3FB|\\U0001F9BB\\U0001F3FC|\\U0001F9BB\\U0001F3FD|\\U0001F9BB\\U0001F3FE|\\U0001F9BB\\U0001F3FF|\\U0001F443\\U0001F3FB|\\U0001F443\\U0001F3FC|\\U0001F443\\U0001F3FD|\\U0001F443\\U0001F3FE|\\U0001F443\\U0001F3FF|\\U0001F441\\U0000FE0F|\\U0001F476\\U0001F3FB|\\U0001F476\\U0001F3FC|\\U0001F476\\U0001F3FD|\\U0001F476\\U0001F3FE|\\U0001F476\\U0001F3FF|\\U0001F9D2\\U0001F3FB|\\U0001F9D2\\U0001F3FC|\\U0001F9D2\\U0001F3FD|\\U0001F9D2\\U0001F3FE|\\U0001F9D2\\U0001F3FF|\\U0001F466\\U0001F3FB|\\U0001F466\\U0001F3FC|\\U0001F466\\U0001F3FD|\\U0001F466\\U0001F3FE|\\U0001F466\\U0001F3FF|\\U0001F467\\U0001F3FB|\\U0001F467\\U0001F3FC|\\U0001F467\\U0001F3FD|\\U0001F467\\U0001F3FE|\\U0001F467\\U0001F3FF|\\U0001F9D1\\U0001F3FB|\\U0001F9D1\\U0001F3FC|\\U0001F9D1\\U0001F3FD|\\U0001F9D1\\U0001F3FE|\\U0001F9D1\\U0001F3FF|\\U0001F471\\U0001F3FB|\\U0001F471\\U0001F3FC|\\U0001F471\\U0001F3FD|\\U0001F471\\U0001F3FE|\\U0001F471\\U0001F3FF|\\U0001F468\\U0001F3FB|\\U0001F468\\U0001F3FC|\\U0001F468\\U0001F3FD|\\U0001F468\\U0001F3FE|\\U0001F468\\U0001F3FF|\\U0001F9D4\\U0001F3FB|\\U0001F9D4\\U0001F3FC|\\U0001F9D4\\U0001F3FD|\\U0001F9D4\\U0001F3FE|\\U0001F9D4\\U0001F3FF|\\U0001F469\\U0001F3FB|\\U0001F469\\U0001F3FC|\\U0001F469\\U0001F3FD|\\U0001F469\\U0001F3FE|\\U0001F469\\U0001F3FF|\\U0001F9D3\\U0001F3FB|\\U0001F9D3\\U0001F3FC|\\U0001F9D3\\U0001F3FD|\\U0001F9D3\\U0001F3FE|\\U0001F9D3\\U0001F3FF|\\U0001F474\\U0001F3FB|\\U0001F474\\U0001F3FC|\\U0001F474\\U0001F3FD|\\U0001F474\\U0001F3FE|\\U0001F474\\U0001F3FF|\\U0001F475\\U0001F3FB|\\U0001F475\\U0001F3FC|\\U0001F475\\U0001F3FD|\\U0001F475\\U0001F3FE|\\U0001F475\\U0001F3FF|\\U0001F64D\\U0001F3FB|\\U0001F64D\\U0001F3FC|\\U0001F64D\\U0001F3FD|\\U0001F64D\\U0001F3FE|\\U0001F64D\\U0001F3FF|\\U0001F64E\\U0001F3FB|\\U0001F64E\\U0001F3FC|\\U0001F64E\\U0001F3FD|\\U0001F64E\\U0001F3FE|\\U0001F64E\\U0001F3FF|\\U0001F645\\U0001F3FB|\\U0001F645\\U0001F3FC|\\U0001F645\\U0001F3FD|\\U0001F645\\U0001F3FE|\\U0001F645\\U0001F3FF|\\U0001F646\\U0001F3FB|\\U0001F646\\U0001F3FC|\\U0001F646\\U0001F3FD|\\U0001F646\\U0001F3FE|\\U0001F646\\U0001F3FF|\\U0001F481\\U0001F3FB|\\U0001F481\\U0001F3FC|\\U0001F481\\U0001F3FD|\\U0001F481\\U0001F3FE|\\U0001F481\\U0001F3FF|\\U0001F64B\\U0001F3FB|\\U0001F64B\\U0001F3FC|\\U0001F64B\\U0001F3FD|\\U0001F64B\\U0001F3FE|\\U0001F64B\\U0001F3FF|\\U0001F9CF\\U0001F3FB|\\U0001F9CF\\U0001F3FC|\\U0001F9CF\\U0001F3FD|\\U0001F9CF\\U0001F3FE|\\U0001F9CF\\U0001F3FF|\\U0001F647\\U0001F3FB|\\U0001F647\\U0001F3FC|\\U0001F647\\U0001F3FD|\\U0001F647\\U0001F3FE|\\U0001F647\\U0001F3FF|\\U0001F926\\U0001F3FB|\\U0001F926\\U0001F3FC|\\U0001F926\\U0001F3FD|\\U0001F926\\U0001F3FE|\\U0001F926\\U0001F3FF|\\U0001F937\\U0001F3FB|\\U0001F937\\U0001F3FC|\\U0001F937\\U0001F3FD|\\U0001F937\\U0001F3FE|\\U0001F937\\U0001F3FF|\\U0001F46E\\U0001F3FB|\\U0001F46E\\U0001F3FC|\\U0001F46E\\U0001F3FD|\\U0001F46E\\U0001F3FE|\\U0001F46E\\U0001F3FF|\\U0001F575\\U0000FE0F|\\U0001F575\\U0001F3FB|\\U0001F575\\U0001F3FC|\\U0001F575\\U0001F3FD|\\U0001F575\\U0001F3FE|\\U0001F575\\U0001F3FF|\\U0001F482\\U0001F3FB|\\U0001F482\\U0001F3FC|\\U0001F482\\U0001F3FD|\\U0001F482\\U0001F3FE|\\U0001F482\\U0001F3FF|\\U0001F977\\U0001F3FB|\\U0001F977\\U0001F3FC|\\U0001F977\\U0001F3FD|\\U0001F977\\U0001F3FE|\\U0001F977\\U0001F3FF|\\U0001F477\\U0001F3FB|\\U0001F477\\U0001F3FC|\\U0001F477\\U0001F3FD|\\U0001F477\\U0001F3FE|\\U0001F477\\U0001F3FF|\\U0001FAC5\\U0001F3FB|\\U0001FAC5\\U0001F3FC|\\U0001FAC5\\U0001F3FD|\\U0001FAC5\\U0001F3FE|\\U0001FAC5\\U0001F3FF|\\U0001F934\\U0001F3FB|\\U0001F934\\U0001F3FC|\\U0001F934\\U0001F3FD|\\U0001F934\\U0001F3FE|\\U0001F934\\U0001F3FF|\\U0001F478\\U0001F3FB|\\U0001F478\\U0001F3FC|\\U0001F478\\U0001F3FD|\\U0001F478\\U0001F3FE|\\U0001F478\\U0001F3FF|\\U0001F473\\U0001F3FB|\\U0001F473\\U0001F3FC|\\U0001F473\\U0001F3FD|\\U0001F473\\U0001F3FE|\\U0001F473\\U0001F3FF|\\U0001F472\\U0001F3FB|\\U0001F472\\U0001F3FC|\\U0001F472\\U0001F3FD|\\U0001F472\\U0001F3FE|\\U0001F472\\U0001F3FF|\\U0001F9D5\\U0001F3FB|\\U0001F9D5\\U0001F3FC|\\U0001F9D5\\U0001F3FD|\\U0001F9D5\\U0001F3FE|\\U0001F9D5\\U0001F3FF|\\U0001F935\\U0001F3FB|\\U0001F935\\U0001F3FC|\\U0001F935\\U0001F3FD|\\U0001F935\\U0001F3FE|\\U0001F935\\U0001F3FF|\\U0001F470\\U0001F3FB|\\U0001F470\\U0001F3FC|\\U0001F470\\U0001F3FD|\\U0001F470\\U0001F3FE|\\U0001F470\\U0001F3FF|\\U0001F930\\U0001F3FB|\\U0001F930\\U0001F3FC|\\U0001F930\\U0001F3FD|\\U0001F930\\U0001F3FE|\\U0001F930\\U0001F3FF|\\U0001FAC3\\U0001F3FB|\\U0001FAC3\\U0001F3FC|\\U0001FAC3\\U0001F3FD|\\U0001FAC3\\U0001F3FE|\\U0001FAC3\\U0001F3FF|\\U0001FAC4\\U0001F3FB|\\U0001FAC4\\U0001F3FC|\\U0001FAC4\\U0001F3FD|\\U0001FAC4\\U0001F3FE|\\U0001FAC4\\U0001F3FF|\\U0001F931\\U0001F3FB|\\U0001F931\\U0001F3FC|\\U0001F931\\U0001F3FD|\\U0001F931\\U0001F3FE|\\U0001F931\\U0001F3FF|\\U0001F47C\\U0001F3FB|\\U0001F47C\\U0001F3FC|\\U0001F47C\\U0001F3FD|\\U0001F47C\\U0001F3FE|\\U0001F47C\\U0001F3FF|\\U0001F385\\U0001F3FB|\\U0001F385\\U0001F3FC|\\U0001F385\\U0001F3FD|\\U0001F385\\U0001F3FE|\\U0001F385\\U0001F3FF|\\U0001F936\\U0001F3FB|\\U0001F936\\U0001F3FC|\\U0001F936\\U0001F3FD|\\U0001F936\\U0001F3FE|\\U0001F936\\U0001F3FF|\\U0001F9B8\\U0001F3FB|\\U0001F9B8\\U0001F3FC|\\U0001F9B8\\U0001F3FD|\\U0001F9B8\\U0001F3FE|\\U0001F9B8\\U0001F3FF|\\U0001F9B9\\U0001F3FB|\\U0001F9B9\\U0001F3FC|\\U0001F9B9\\U0001F3FD|\\U0001F9B9\\U0001F3FE|\\U0001F9B9\\U0001F3FF|\\U0001F9D9\\U0001F3FB|\\U0001F9D9\\U0001F3FC|\\U0001F9D9\\U0001F3FD|\\U0001F9D9\\U0001F3FE|\\U0001F9D9\\U0001F3FF|\\U0001F9DA\\U0001F3FB|\\U0001F9DA\\U0001F3FC|\\U0001F9DA\\U0001F3FD|\\U0001F9DA\\U0001F3FE|\\U0001F9DA\\U0001F3FF|\\U0001F9DB\\U0001F3FB|\\U0001F9DB\\U0001F3FC|\\U0001F9DB\\U0001F3FD|\\U0001F9DB\\U0001F3FE|\\U0001F9DB\\U0001F3FF|\\U0001F9DC\\U0001F3FB|\\U0001F9DC\\U0001F3FC|\\U0001F9DC\\U0001F3FD|\\U0001F9DC\\U0001F3FE|\\U0001F9DC\\U0001F3FF|\\U0001F9DD\\U0001F3FB|\\U0001F9DD\\U0001F3FC|\\U0001F9DD\\U0001F3FD|\\U0001F9DD\\U0001F3FE|\\U0001F9DD\\U0001F3FF|\\U0001F486\\U0001F3FB|\\U0001F486\\U0001F3FC|\\U0001F486\\U0001F3FD|\\U0001F486\\U0001F3FE|\\U0001F486\\U0001F3FF|\\U0001F487\\U0001F3FB|\\U0001F487\\U0001F3FC|\\U0001F487\\U0001F3FD|\\U0001F487\\U0001F3FE|\\U0001F487\\U0001F3FF|\\U0001F6B6\\U0001F3FB|\\U0001F6B6\\U0001F3FC|\\U0001F6B6\\U0001F3FD|\\U0001F6B6\\U0001F3FE|\\U0001F6B6\\U0001F3FF|\\U0001F9CD\\U0001F3FB|\\U0001F9CD\\U0001F3FC|\\U0001F9CD\\U0001F3FD|\\U0001F9CD\\U0001F3FE|\\U0001F9CD\\U0001F3FF|\\U0001F9CE\\U0001F3FB|\\U0001F9CE\\U0001F3FC|\\U0001F9CE\\U0001F3FD|\\U0001F9CE\\U0001F3FE|\\U0001F9CE\\U0001F3FF|\\U0001F3C3\\U0001F3FB|\\U0001F3C3\\U0001F3FC|\\U0001F3C3\\U0001F3FD|\\U0001F3C3\\U0001F3FE|\\U0001F3C3\\U0001F3FF|\\U0001F483\\U0001F3FB|\\U0001F483\\U0001F3FC|\\U0001F483\\U0001F3FD|\\U0001F483\\U0001F3FE|\\U0001F483\\U0001F3FF|\\U0001F57A\\U0001F3FB|\\U0001F57A\\U0001F3FC|\\U0001F57A\\U0001F3FD|\\U0001F57A\\U0001F3FE|\\U0001F57A\\U0001F3FF|\\U0001F574\\U0000FE0F|\\U0001F574\\U0001F3FB|\\U0001F574\\U0001F3FC|\\U0001F574\\U0001F3FD|\\U0001F574\\U0001F3FE|\\U0001F574\\U0001F3FF|\\U0001F9D6\\U0001F3FB|\\U0001F9D6\\U0001F3FC|\\U0001F9D6\\U0001F3FD|\\U0001F9D6\\U0001F3FE|\\U0001F9D6\\U0001F3FF|\\U0001F9D7\\U0001F3FB|\\U0001F9D7\\U0001F3FC|\\U0001F9D7\\U0001F3FD|\\U0001F9D7\\U0001F3FE|\\U0001F9D7\\U0001F3FF|\\U0001F3C7\\U0001F3FB|\\U0001F3C7\\U0001F3FC|\\U0001F3C7\\U0001F3FD|\\U0001F3C7\\U0001F3FE|\\U0001F3C7\\U0001F3FF|\\U000026F7\\U0000FE0F|\\U0001F3C2\\U0001F3FB|\\U0001F3C2\\U0001F3FC|\\U0001F3C2\\U0001F3FD|\\U0001F3C2\\U0001F3FE|\\U0001F3C2\\U0001F3FF|\\U0001F3CC\\U0000FE0F|\\U0001F3CC\\U0001F3FB|\\U0001F3CC\\U0001F3FC|\\U0001F3CC\\U0001F3FD|\\U0001F3CC\\U0001F3FE|\\U0001F3CC\\U0001F3FF|\\U0001F3C4\\U0001F3FB|\\U0001F3C4\\U0001F3FC|\\U0001F3C4\\U0001F3FD|\\U0001F3C4\\U0001F3FE|\\U0001F3C4\\U0001F3FF|\\U0001F6A3\\U0001F3FB|\\U0001F6A3\\U0001F3FC|\\U0001F6A3\\U0001F3FD|\\U0001F6A3\\U0001F3FE|\\U0001F6A3\\U0001F3FF|\\U0001F3CA\\U0001F3FB|\\U0001F3CA\\U0001F3FC|\\U0001F3CA\\U0001F3FD|\\U0001F3CA\\U0001F3FE|\\U0001F3CA\\U0001F3FF|\\U000026F9\\U0000FE0F|\\U000026F9\\U0001F3FB|\\U000026F9\\U0001F3FC|\\U000026F9\\U0001F3FD|\\U000026F9\\U0001F3FE|\\U000026F9\\U0001F3FF|\\U0001F3CB\\U0000FE0F|\\U0001F3CB\\U0001F3FB|\\U0001F3CB\\U0001F3FC|\\U0001F3CB\\U0001F3FD|\\U0001F3CB\\U0001F3FE|\\U0001F3CB\\U0001F3FF|\\U0001F6B4\\U0001F3FB|\\U0001F6B4\\U0001F3FC|\\U0001F6B4\\U0001F3FD|\\U0001F6B4\\U0001F3FE|\\U0001F6B4\\U0001F3FF|\\U0001F6B5\\U0001F3FB|\\U0001F6B5\\U0001F3FC|\\U0001F6B5\\U0001F3FD|\\U0001F6B5\\U0001F3FE|\\U0001F6B5\\U0001F3FF|\\U0001F938\\U0001F3FB|\\U0001F938\\U0001F3FC|\\U0001F938\\U0001F3FD|\\U0001F938\\U0001F3FE|\\U0001F938\\U0001F3FF|\\U0001F93D\\U0001F3FB|\\U0001F93D\\U0001F3FC|\\U0001F93D\\U0001F3FD|\\U0001F93D\\U0001F3FE|\\U0001F93D\\U0001F3FF|\\U0001F93E\\U0001F3FB|\\U0001F93E\\U0001F3FC|\\U0001F93E\\U0001F3FD|\\U0001F93E\\U0001F3FE|\\U0001F93E\\U0001F3FF|\\U0001F939\\U0001F3FB|\\U0001F939\\U0001F3FC|\\U0001F939\\U0001F3FD|\\U0001F939\\U0001F3FE|\\U0001F939\\U0001F3FF|\\U0001F9D8\\U0001F3FB|\\U0001F9D8\\U0001F3FC|\\U0001F9D8\\U0001F3FD|\\U0001F9D8\\U0001F3FE|\\U0001F9D8\\U0001F3FF|\\U0001F6C0\\U0001F3FB|\\U0001F6C0\\U0001F3FC|\\U0001F6C0\\U0001F3FD|\\U0001F6C0\\U0001F3FE|\\U0001F6C0\\U0001F3FF|\\U0001F6CC\\U0001F3FB|\\U0001F6CC\\U0001F3FC|\\U0001F6CC\\U0001F3FD|\\U0001F6CC\\U0001F3FE|\\U0001F6CC\\U0001F3FF|\\U0001F46D\\U0001F3FB|\\U0001F46D\\U0001F3FC|\\U0001F46D\\U0001F3FD|\\U0001F46D\\U0001F3FE|\\U0001F46D\\U0001F3FF|\\U0001F46B\\U0001F3FB|\\U0001F46B\\U0001F3FC|\\U0001F46B\\U0001F3FD|\\U0001F46B\\U0001F3FE|\\U0001F46B\\U0001F3FF|\\U0001F46C\\U0001F3FB|\\U0001F46C\\U0001F3FC|\\U0001F46C\\U0001F3FD|\\U0001F46C\\U0001F3FE|\\U0001F46C\\U0001F3FF|\\U0001F48F\\U0001F3FB|\\U0001F48F\\U0001F3FC|\\U0001F48F\\U0001F3FD|\\U0001F48F\\U0001F3FE|\\U0001F48F\\U0001F3FF|\\U0001F491\\U0001F3FB|\\U0001F491\\U0001F3FC|\\U0001F491\\U0001F3FD|\\U0001F491\\U0001F3FE|\\U0001F491\\U0001F3FF|\\U0001F5E3\\U0000FE0F|\\U0001F43F\\U0000FE0F|\\U0001F54A\\U0000FE0F|\\U0001F577\\U0000FE0F|\\U0001F578\\U0000FE0F|\\U0001F3F5\\U0000FE0F|\\U00002618\\U0000FE0F|\\U0001F336\\U0000FE0F|\\U0001F37D\\U0000FE0F|\\U0001F5FA\\U0000FE0F|\\U0001F3D4\\U0000FE0F|\\U000026F0\\U0000FE0F|\\U0001F3D5\\U0000FE0F|\\U0001F3D6\\U0000FE0F|\\U0001F3DC\\U0000FE0F|\\U0001F3DD\\U0000FE0F|\\U0001F3DE\\U0000FE0F|\\U0001F3DF\\U0000FE0F|\\U0001F3DB\\U0000FE0F|\\U0001F3D7\\U0000FE0F|\\U0001F3D8\\U0000FE0F|\\U0001F3DA\\U0000FE0F|\\U000026E9\\U0000FE0F|\\U0001F3D9\\U0000FE0F|\\U00002668\\U0000FE0F|\\U0001F3CE\\U0000FE0F|\\U0001F3CD\\U0000FE0F|\\U0001F6E3\\U0000FE0F|\\U0001F6E4\\U0000FE0F|\\U0001F6E2\\U0000FE0F|\\U0001F6F3\\U0000FE0F|\\U000026F4\\U0000FE0F|\\U0001F6E5\\U0000FE0F|\\U00002708\\U0000FE0F|\\U0001F6E9\\U0000FE0F|\\U0001F6F0\\U0000FE0F|\\U0001F6CE\\U0000FE0F|\\U000023F1\\U0000FE0F|\\U000023F2\\U0000FE0F|\\U0001F570\\U0000FE0F|\\U0001F321\\U0000FE0F|\\U00002600\\U0000FE0F|\\U00002601\\U0000FE0F|\\U000026C8\\U0000FE0F|\\U0001F324\\U0000FE0F|\\U0001F325\\U0000FE0F|\\U0001F326\\U0000FE0F|\\U0001F327\\U0000FE0F|\\U0001F328\\U0000FE0F|\\U0001F329\\U0000FE0F|\\U0001F32A\\U0000FE0F|\\U0001F32B\\U0000FE0F|\\U0001F32C\\U0000FE0F|\\U00002602\\U0000FE0F|\\U000026F1\\U0000FE0F|\\U00002744\\U0000FE0F|\\U00002603\\U0000FE0F|\\U00002604\\U0000FE0F|\\U0001F397\\U0000FE0F|\\U0001F39F\\U0000FE0F|\\U0001F396\\U0000FE0F|\\U000026F8\\U0000FE0F|\\U0001F579\\U0000FE0F|\\U00002660\\U0000FE0F|\\U00002665\\U0000FE0F|\\U00002666\\U0000FE0F|\\U00002663\\U0000FE0F|\\U0000265F\\U0000FE0F|\\U0001F5BC\\U0000FE0F|\\U0001F576\\U0000FE0F|\\U0001F6CD\\U0000FE0F|\\U000026D1\\U0000FE0F|\\U0001F399\\U0000FE0F|\\U0001F39A\\U0000FE0F|\\U0001F39B\\U0000FE0F|\\U0000260E\\U0000FE0F|\\U0001F5A5\\U0000FE0F|\\U0001F5A8\\U0000FE0F|\\U00002328\\U0000FE0F|\\U0001F5B1\\U0000FE0F|\\U0001F5B2\\U0000FE0F|\\U0001F39E\\U0000FE0F|\\U0001F4FD\\U0000FE0F|\\U0001F56F\\U0000FE0F|\\U0001F5DE\\U0000FE0F|\\U0001F3F7\\U0000FE0F|\\U00002709\\U0000FE0F|\\U0001F5F3\\U0000FE0F|\\U0000270F\\U0000FE0F|\\U00002712\\U0000FE0F|\\U0001F58B\\U0000FE0F|\\U0001F58A\\U0000FE0F|\\U0001F58C\\U0000FE0F|\\U0001F58D\\U0000FE0F|\\U0001F5C2\\U0000FE0F|\\U0001F5D2\\U0000FE0F|\\U0001F5D3\\U0000FE0F|\\U0001F587\\U0000FE0F|\\U00002702\\U0000FE0F|\\U0001F5C3\\U0000FE0F|\\U0001F5C4\\U0000FE0F|\\U0001F5D1\\U0000FE0F|\\U0001F5DD\\U0000FE0F|\\U000026CF\\U0000FE0F|\\U00002692\\U0000FE0F|\\U0001F6E0\\U0000FE0F|\\U0001F5E1\\U0000FE0F|\\U00002694\\U0000FE0F|\\U0001F6E1\\U0000FE0F|\\U00002699\\U0000FE0F|\\U0001F5DC\\U0000FE0F|\\U00002696\\U0000FE0F|\\U000026D3\\U0000FE0F|\\U00002697\\U0000FE0F|\\U0001F6CF\\U0000FE0F|\\U0001F6CB\\U0000FE0F|\\U000026B0\\U0000FE0F|\\U000026B1\\U0000FE0F|\\U000026A0\\U0000FE0F|\\U00002622\\U0000FE0F|\\U00002623\\U0000FE0F|\\U00002B06\\U0000FE0F|\\U00002197\\U0000FE0F|\\U000027A1\\U0000FE0F|\\U00002198\\U0000FE0F|\\U00002B07\\U0000FE0F|\\U00002199\\U0000FE0F|\\U00002B05\\U0000FE0F|\\U00002196\\U0000FE0F|\\U00002195\\U0000FE0F|\\U00002194\\U0000FE0F|\\U000021A9\\U0000FE0F|\\U000021AA\\U0000FE0F|\\U00002934\\U0000FE0F|\\U00002935\\U0000FE0F|\\U0000269B\\U0000FE0F|\\U0001F549\\U0000FE0F|\\U00002721\\U0000FE0F|\\U00002638\\U0000FE0F|\\U0000262F\\U0000FE0F|\\U0000271D\\U0000FE0F|\\U00002626\\U0000FE0F|\\U0000262A\\U0000FE0F|\\U0000262E\\U0000FE0F|\\U000025B6\\U0000FE0F|\\U000023ED\\U0000FE0F|\\U000023EF\\U0000FE0F|\\U000025C0\\U0000FE0F|\\U000023EE\\U0000FE0F|\\U000023F8\\U0000FE0F|\\U000023F9\\U0000FE0F|\\U000023FA\\U0000FE0F|\\U000023CF\\U0000FE0F|\\U00002640\\U0000FE0F|\\U00002642\\U0000FE0F|\\U000026A7\\U0000FE0F|\\U00002716\\U0000FE0F|\\U0000267E\\U0000FE0F|\\U0000203C\\U0000FE0F|\\U00002049\\U0000FE0F|\\U00003030\\U0000FE0F|\\U00002695\\U0000FE0F|\\U0000267B\\U0000FE0F|\\U0000269C\\U0000FE0F|\\U00002611\\U0000FE0F|\\U00002714\\U0000FE0F|\\U0000303D\\U0000FE0F|\\U00002733\\U0000FE0F|\\U00002734\\U0000FE0F|\\U00002747\\U0000FE0F|\\U000000A9\\U0000FE0F|\\U000000AE\\U0000FE0F|\\U00002122\\U0000FE0F|\\U00000023\\U000020E3|\\U0000002A\\U000020E3|\\U00000030\\U000020E3|\\U00000031\\U000020E3|\\U00000032\\U000020E3|\\U00000033\\U000020E3|\\U00000034\\U000020E3|\\U00000035\\U000020E3|\\U00000036\\U000020E3|\\U00000037\\U000020E3|\\U00000038\\U000020E3|\\U00000039\\U000020E3|\\U0001F170\\U0000FE0F|\\U0001F171\\U0000FE0F|\\U00002139\\U0000FE0F|\\U000024C2\\U0000FE0F|\\U0001F17E\\U0000FE0F|\\U0001F17F\\U0000FE0F|\\U0001F202\\U0000FE0F|\\U0001F237\\U0000FE0F|\\U00003297\\U0000FE0F|\\U00003299\\U0000FE0F|\\U000025FC\\U0000FE0F|\\U000025FB\\U0000FE0F|\\U000025AA\\U0000FE0F|\\U000025AB\\U0000FE0F|\\U0001F3F3\\U0000FE0F|\\U0001F1E6\\U0001F1E8|\\U0001F1E6\\U0001F1E9|\\U0001F1E6\\U0001F1EA|\\U0001F1E6\\U0001F1EB|\\U0001F1E6\\U0001F1EC|\\U0001F1E6\\U0001F1EE|\\U0001F1E6\\U0001F1F1|\\U0001F1E6\\U0001F1F2|\\U0001F1E6\\U0001F1F4|\\U0001F1E6\\U0001F1F6|\\U0001F1E6\\U0001F1F7|\\U0001F1E6\\U0001F1F8|\\U0001F1E6\\U0001F1F9|\\U0001F1E6\\U0001F1FA|\\U0001F1E6\\U0001F1FC|\\U0001F1E6\\U0001F1FD|\\U0001F1E6\\U0001F1FF|\\U0001F1E7\\U0001F1E6|\\U0001F1E7\\U0001F1E7|\\U0001F1E7\\U0001F1E9|\\U0001F1E7\\U0001F1EA|\\U0001F1E7\\U0001F1EB|\\U0001F1E7\\U0001F1EC|\\U0001F1E7\\U0001F1ED|\\U0001F1E7\\U0001F1EE|\\U0001F1E7\\U0001F1EF|\\U0001F1E7\\U0001F1F1|\\U0001F1E7\\U0001F1F2|\\U0001F1E7\\U0001F1F3|\\U0001F1E7\\U0001F1F4|\\U0001F1E7\\U0001F1F6|\\U0001F1E7\\U0001F1F7|\\U0001F1E7\\U0001F1F8|\\U0001F1E7\\U0001F1F9|\\U0001F1E7\\U0001F1FB|\\U0001F1E7\\U0001F1FC|\\U0001F1E7\\U0001F1FE|\\U0001F1E7\\U0001F1FF|\\U0001F1E8\\U0001F1E6|\\U0001F1E8\\U0001F1E8|\\U0001F1E8\\U0001F1E9|\\U0001F1E8\\U0001F1EB|\\U0001F1E8\\U0001F1EC|\\U0001F1E8\\U0001F1ED|\\U0001F1E8\\U0001F1EE|\\U0001F1E8\\U0001F1F0|\\U0001F1E8\\U0001F1F1|\\U0001F1E8\\U0001F1F2|\\U0001F1E8\\U0001F1F3|\\U0001F1E8\\U0001F1F4|\\U0001F1E8\\U0001F1F5|\\U0001F1E8\\U0001F1F7|\\U0001F1E8\\U0001F1FA|\\U0001F1E8\\U0001F1FB|\\U0001F1E8\\U0001F1FC|\\U0001F1E8\\U0001F1FD|\\U0001F1E8\\U0001F1FE|\\U0001F1E8\\U0001F1FF|\\U0001F1E9\\U0001F1EA|\\U0001F1E9\\U0001F1EC|\\U0001F1E9\\U0001F1EF|\\U0001F1E9\\U0001F1F0|\\U0001F1E9\\U0001F1F2|\\U0001F1E9\\U0001F1F4|\\U0001F1E9\\U0001F1FF|\\U0001F1EA\\U0001F1E6|\\U0001F1EA\\U0001F1E8|\\U0001F1EA\\U0001F1EA|\\U0001F1EA\\U0001F1EC|\\U0001F1EA\\U0001F1ED|\\U0001F1EA\\U0001F1F7|\\U0001F1EA\\U0001F1F8|\\U0001F1EA\\U0001F1F9|\\U0001F1EA\\U0001F1FA|\\U0001F1EB\\U0001F1EE|\\U0001F1EB\\U0001F1EF|\\U0001F1EB\\U0001F1F0|\\U0001F1EB\\U0001F1F2|\\U0001F1EB\\U0001F1F4|\\U0001F1EB\\U0001F1F7|\\U0001F1EC\\U0001F1E6|\\U0001F1EC\\U0001F1E7|\\U0001F1EC\\U0001F1E9|\\U0001F1EC\\U0001F1EA|\\U0001F1EC\\U0001F1EB|\\U0001F1EC\\U0001F1EC|\\U0001F1EC\\U0001F1ED|\\U0001F1EC\\U0001F1EE|\\U0001F1EC\\U0001F1F1|\\U0001F1EC\\U0001F1F2|\\U0001F1EC\\U0001F1F3|\\U0001F1EC\\U0001F1F5|\\U0001F1EC\\U0001F1F6|\\U0001F1EC\\U0001F1F7|\\U0001F1EC\\U0001F1F8|\\U0001F1EC\\U0001F1F9|\\U0001F1EC\\U0001F1FA|\\U0001F1EC\\U0001F1FC|\\U0001F1EC\\U0001F1FE|\\U0001F1ED\\U0001F1F0|\\U0001F1ED\\U0001F1F2|\\U0001F1ED\\U0001F1F3|\\U0001F1ED\\U0001F1F7|\\U0001F1ED\\U0001F1F9|\\U0001F1ED\\U0001F1FA|\\U0001F1EE\\U0001F1E8|\\U0001F1EE\\U0001F1E9|\\U0001F1EE\\U0001F1EA|\\U0001F1EE\\U0001F1F1|\\U0001F1EE\\U0001F1F2|\\U0001F1EE\\U0001F1F3|\\U0001F1EE\\U0001F1F4|\\U0001F1EE\\U0001F1F6|\\U0001F1EE\\U0001F1F7|\\U0001F1EE\\U0001F1F8|\\U0001F1EE\\U0001F1F9|\\U0001F1EF\\U0001F1EA|\\U0001F1EF\\U0001F1F2|\\U0001F1EF\\U0001F1F4|\\U0001F1EF\\U0001F1F5|\\U0001F1F0\\U0001F1EA|\\U0001F1F0\\U0001F1EC|\\U0001F1F0\\U0001F1ED|\\U0001F1F0\\U0001F1EE|\\U0001F1F0\\U0001F1F2|\\U0001F1F0\\U0001F1F3|\\U0001F1F0\\U0001F1F5|\\U0001F1F0\\U0001F1F7|\\U0001F1F0\\U0001F1FC|\\U0001F1F0\\U0001F1FE|\\U0001F1F0\\U0001F1FF|\\U0001F1F1\\U0001F1E6|\\U0001F1F1\\U0001F1E7|\\U0001F1F1\\U0001F1E8|\\U0001F1F1\\U0001F1EE|\\U0001F1F1\\U0001F1F0|\\U0001F1F1\\U0001F1F7|\\U0001F1F1\\U0001F1F8|\\U0001F1F1\\U0001F1F9|\\U0001F1F1\\U0001F1FA|\\U0001F1F1\\U0001F1FB|\\U0001F1F1\\U0001F1FE|\\U0001F1F2\\U0001F1E6|\\U0001F1F2\\U0001F1E8|\\U0001F1F2\\U0001F1E9|\\U0001F1F2\\U0001F1EA|\\U0001F1F2\\U0001F1EB|\\U0001F1F2\\U0001F1EC|\\U0001F1F2\\U0001F1ED|\\U0001F1F2\\U0001F1F0|\\U0001F1F2\\U0001F1F1|\\U0001F1F2\\U0001F1F2|\\U0001F1F2\\U0001F1F3|\\U0001F1F2\\U0001F1F4|\\U0001F1F2\\U0001F1F5|\\U0001F1F2\\U0001F1F6|\\U0001F1F2\\U0001F1F7|\\U0001F1F2\\U0001F1F8|\\U0001F1F2\\U0001F1F9|\\U0001F1F2\\U0001F1FA|\\U0001F1F2\\U0001F1FB|\\U0001F1F2\\U0001F1FC|\\U0001F1F2\\U0001F1FD|\\U0001F1F2\\U0001F1FE|\\U0001F1F2\\U0001F1FF|\\U0001F1F3\\U0001F1E6|\\U0001F1F3\\U0001F1E8|\\U0001F1F3\\U0001F1EA|\\U0001F1F3\\U0001F1EB|\\U0001F1F3\\U0001F1EC|\\U0001F1F3\\U0001F1EE|\\U0001F1F3\\U0001F1F1|\\U0001F1F3\\U0001F1F4|\\U0001F1F3\\U0001F1F5|\\U0001F1F3\\U0001F1F7|\\U0001F1F3\\U0001F1FA|\\U0001F1F3\\U0001F1FF|\\U0001F1F4\\U0001F1F2|\\U0001F1F5\\U0001F1E6|\\U0001F1F5\\U0001F1EA|\\U0001F1F5\\U0001F1EB|\\U0001F1F5\\U0001F1EC|\\U0001F1F5\\U0001F1ED|\\U0001F1F5\\U0001F1F0|\\U0001F1F5\\U0001F1F1|\\U0001F1F5\\U0001F1F2|\\U0001F1F5\\U0001F1F3|\\U0001F1F5\\U0001F1F7|\\U0001F1F5\\U0001F1F8|\\U0001F1F5\\U0001F1F9|\\U0001F1F5\\U0001F1FC|\\U0001F1F5\\U0001F1FE|\\U0001F1F6\\U0001F1E6|\\U0001F1F7\\U0001F1EA|\\U0001F1F7\\U0001F1F4|\\U0001F1F7\\U0001F1F8|\\U0001F1F7\\U0001F1FA|\\U0001F1F7\\U0001F1FC|\\U0001F1F8\\U0001F1E6|\\U0001F1F8\\U0001F1E7|\\U0001F1F8\\U0001F1E8|\\U0001F1F8\\U0001F1E9|\\U0001F1F8\\U0001F1EA|\\U0001F1F8\\U0001F1EC|\\U0001F1F8\\U0001F1ED|\\U0001F1F8\\U0001F1EE|\\U0001F1F8\\U0001F1EF|\\U0001F1F8\\U0001F1F0|\\U0001F1F8\\U0001F1F1|\\U0001F1F8\\U0001F1F2|\\U0001F1F8\\U0001F1F3|\\U0001F1F8\\U0001F1F4|\\U0001F1F8\\U0001F1F7|\\U0001F1F8\\U0001F1F8|\\U0001F1F8\\U0001F1F9|\\U0001F1F8\\U0001F1FB|\\U0001F1F8\\U0001F1FD|\\U0001F1F8\\U0001F1FE|\\U0001F1F8\\U0001F1FF|\\U0001F1F9\\U0001F1E6|\\U0001F1F9\\U0001F1E8|\\U0001F1F9\\U0001F1E9|\\U0001F1F9\\U0001F1EB|\\U0001F1F9\\U0001F1EC|\\U0001F1F9\\U0001F1ED|\\U0001F1F9\\U0001F1EF|\\U0001F1F9\\U0001F1F0|\\U0001F1F9\\U0001F1F1|\\U0001F1F9\\U0001F1F2|\\U0001F1F9\\U0001F1F3|\\U0001F1F9\\U0001F1F4|\\U0001F1F9\\U0001F1F7|\\U0001F1F9\\U0001F1F9|\\U0001F1F9\\U0001F1FB|\\U0001F1F9\\U0001F1FC|\\U0001F1F9\\U0001F1FF|\\U0001F1FA\\U0001F1E6|\\U0001F1FA\\U0001F1EC|\\U0001F1FA\\U0001F1F2|\\U0001F1FA\\U0001F1F3|\\U0001F1FA\\U0001F1F8|\\U0001F1FA\\U0001F1FE|\\U0001F1FA\\U0001F1FF|\\U0001F1FB\\U0001F1E6|\\U0001F1FB\\U0001F1E8|\\U0001F1FB\\U0001F1EA|\\U0001F1FB\\U0001F1EC|\\U0001F1FB\\U0001F1EE|\\U0001F1FB\\U0001F1F3|\\U0001F1FB\\U0001F1FA|\\U0001F1FC\\U0001F1EB|\\U0001F1FC\\U0001F1F8|\\U0001F1FD\\U0001F1F0|\\U0001F1FE\\U0001F1EA|\\U0001F1FE\\U0001F1F9|\\U0001F1FF\\U0001F1E6|\\U0001F1FF\\U0001F1F2|\\U0001F1FF\\U0001F1FC|[\\U000000a9\\U000000ae\\U0000203c\\U00002049\\U00002122\\U00002139\\U00002194-\\U00002199\\U000021a9-\\U000021aa\\U0000231a-\\U0000231b\\U00002328\\U000023cf\\U000023e9-\\U000023f3\\U000023f8-\\U000023fa\\U000024c2\\U000025aa-\\U000025ab\\U000025b6\\U000025c0\\U000025fb-\\U000025fe\\U00002600-\\U00002604\\U0000260e\\U00002611\\U00002614-\\U00002615\\U00002618\\U0000261d\\U00002620\\U00002622-\\U00002623\\U00002626\\U0000262a\\U0000262e-\\U0000262f\\U00002638-\\U0000263a\\U00002640\\U00002642\\U00002648-\\U00002653\\U0000265f-\\U00002660\\U00002663\\U00002665-\\U00002666\\U00002668\\U0000267b\\U0000267e-\\U0000267f\\U00002692-\\U00002697\\U00002699\\U0000269b-\\U0000269c\\U000026a0-\\U000026a1\\U000026a7\\U000026aa-\\U000026ab\\U000026b0-\\U000026b1\\U000026bd-\\U000026be\\U000026c4-\\U000026c5\\U000026c8\\U000026ce-\\U000026cf\\U000026d1\\U000026d3-\\U000026d4\\U000026e9-\\U000026ea\\U000026f0-\\U000026f5\\U000026f7-\\U000026fa\\U000026fd\\U00002702\\U00002705\\U00002708-\\U0000270d\\U0000270f\\U00002712\\U00002714\\U00002716\\U0000271d\\U00002721\\U00002728\\U00002733-\\U00002734\\U00002744\\U00002747\\U0000274c\\U0000274e\\U00002753-\\U00002755\\U00002757\\U00002763-\\U00002764\\U00002795-\\U00002797\\U000027a1\\U000027b0\\U000027bf\\U00002934-\\U00002935\\U00002b05-\\U00002b07\\U00002b1b-\\U00002b1c\\U00002b50\\U00002b55\\U00003030\\U0000303d\\U00003297\\U00003299\\U0001f004\\U0001f0cf\\U0001f170-\\U0001f171\\U0001f17e-\\U0001f17f\\U0001f18e\\U0001f191-\\U0001f19a\\U0001f201-\\U0001f202\\U0001f21a\\U0001f22f\\U0001f232-\\U0001f23a\\U0001f250-\\U0001f251\\U0001f300-\\U0001f321\\U0001f324-\\U0001f393\\U0001f396-\\U0001f397\\U0001f399-\\U0001f39b\\U0001f39e-\\U0001f3f0\\U0001f3f3-\\U0001f3f5\\U0001f3f7-\\U0001f3fa\\U0001f400-\\U0001f4fd\\U0001f4ff-\\U0001f53d\\U0001f549-\\U0001f54e\\U0001f550-\\U0001f567\\U0001f56f-\\U0001f570\\U0001f573-\\U0001f57a\\U0001f587\\U0001f58a-\\U0001f58d\\U0001f590\\U0001f595-\\U0001f596\\U0001f5a4-\\U0001f5a5\\U0001f5a8\\U0001f5b1-\\U0001f5b2\\U0001f5bc\\U0001f5c2-\\U0001f5c4\\U0001f5d1-\\U0001f5d3\\U0001f5dc-\\U0001f5de\\U0001f5e1\\U0001f5e3\\U0001f5e8\\U0001f5ef\\U0001f5f3\\U0001f5fa-\\U0001f64f\\U0001f680-\\U0001f6c5\\U0001f6cb-\\U0001f6d2\\U0001f6d5-\\U0001f6d7\\U0001f6dc-\\U0001f6e5\\U0001f6e9\\U0001f6eb-\\U0001f6ec\\U0001f6f0\\U0001f6f3-\\U0001f6fc\\U0001f7e0-\\U0001f7eb\\U0001f7f0\\U0001f90c-\\U0001f93a\\U0001f93c-\\U0001f945\\U0001f947-\\U0001f9af\\U0001f9b4-\\U0001f9ff\\U0001fa70-\\U0001fa7c\\U0001fa80-\\U0001fa88\\U0001fa90-\\U0001fabd\\U0001fabf-\\U0001fac5\\U0001face-\\U0001fadb\\U0001fae0-\\U0001fae8\\U0001faf0-\\U0001faf8]"

EMOJI = re.compile(EMOJI_RAW)


def _emoji_entries(emoji):
    emoji_df = pd.read_parquet(
        "advertools/emoji_df.parquet",
        columns=["emoji", "name", "group", "sub_group"],
        filters=[("emoji", "in", set(emoji))],
    )
    entries = {record["emoji"]: record for record in emoji_df.to_dict("records")}
    return entries


def extract_emoji(text_list):
    """Return a summary dictionary about emoji in ``text_list``

    Get a summary of the number of emoji, their frequency, the top
    ones, and more.

    :param list text_list: A list of text strings.
    :returns summary: A dictionary with various stats about emoji

    >>> posts = ['I am grinning 😀','A grinning cat 😺',
    ...          'hello! 😀😀😀 💛💛', 'Just text']

    >>> emoji_summary = extract_emoji(posts)
    >>> emoji_summary.keys()
    dict_keys(['emoji', 'emoji_text', 'emoji_flat', 'emoji_flat_text',
    'emoji_counts', 'emoji_freq', 'top_emoji', 'top_emoji_text',
    'top_emoji_groups', 'top_emoji_sub_groups', 'overview'])


    >>> emoji_summary['emoji']
    [['😀'], ['😺'], ['😀', '😀', '😀', '💛', '💛'], []]

    >>> emoji_summary['emoji_text']
    [['grinning face'], ['grinning cat'], ['grinning face', 'grinning face',
      'grinning face', 'yellow heart', 'yellow heart'], []]

    A simple extract of emoji from each of the posts. An empty
    list if none exist

    >>> emoji_summary['emoji_flat']
    ['😀', '😺', '😀', '😀', '😀', '💛', '💛']

    >>> emoji_summary['emoji_flat_text']
    ['grinning face', 'grinning cat', 'grinning face', 'grinning face',
    'grinning face', 'yellow heart', 'yellow heart']

    All emoji in one flat list.

    >>> emoji_summary['emoji_counts']
    [1, 1, 5, 0]

    The count of emoji per post.

    >>> emoji_summary['emoji_freq']
    [(0, 1), (1, 2), (5, 1)]

    Shows how many posts had 0, 1, 2, 3, etc. emoji
    (number_of_emoji, count)

    >>> emoji_summary['top_emoji']
    [('😀', 4), ('💛', 2), ('😺', 1)]

    >>> emoji_summary['top_emoji_text']
    [('grinning face', 4), ('yellow heart', 2),
     ('grinning cat', 1)]

    >>> emoji_summary['top_emoji_groups']
    [('Smileys & Emotion', 7)]

    >>> emoji_summary['top_emoji_sub_groups']
    [('face-smiling', 4), ('emotion', 2), ('cat-face', 1)]

    >>> emoji_summary['overview']
    {'num_posts': 4,
     'num_emoji': 7,
     'emoji_per_post': 1.75,
     'unique_emoji': 3}
    """
    emoji = [re.findall(EMOJI, text.lower()) for text in text_list]
    emoji_flat = [item for sublist in emoji for item in sublist]
    emoji_entries = _emoji_entries(emoji_flat)
    emoji_flat_text = [emoji_entries[em]["name"] for em in emoji_flat]
    emoji_groups = [emoji_entries[em]["group"] for em in emoji_flat]
    emoji_sub_groups = [emoji_entries[em]["sub_group"] for em in emoji_flat]
    summary = {
        "emoji": emoji,
        "emoji_text": [
            [emoji_entries[em]["name"] for em in em_list] for em_list in emoji
        ],
        "emoji_flat": emoji_flat,
        "emoji_flat_text": emoji_flat_text,
        "emoji_counts": [len(em) for em in emoji],
        "emoji_freq": sorted(
            Counter([len(em) for em in emoji]).items(), key=lambda x: x[0]
        ),
        "top_emoji": sorted(
            Counter(emoji_flat).items(), key=lambda x: x[1], reverse=True
        ),
        "top_emoji_text": sorted(
            Counter(emoji_flat_text).items(), key=lambda x: x[1], reverse=True
        ),
        "top_emoji_groups": sorted(
            Counter(emoji_groups).items(), key=lambda x: x[1], reverse=True
        ),
        "top_emoji_sub_groups": sorted(
            Counter(emoji_sub_groups).items(), key=lambda x: x[1], reverse=True
        ),
        "overview": {
            "num_posts": len(text_list),
            "num_emoji": len(emoji_flat),
            "emoji_per_post": len(emoji_flat) / len(text_list),
            "unique_emoji": len(set(emoji_flat)),
        },
    }
    return summary


def emoji_search(regex):
    """Return a DataFrame of all emoji entries that match :attr:`regex`.

    The search is run on the name of the emoji, its group, and sub-group.

    :param str regex: regular expression (case insensitive)

    >>> import advertools as adv
    >>> adv.emoji_search('dog')
              codepoint           status  emoji          name             group        sub_group
    0             1F436  fully-qualified     🐶      dog face  Animals & Nature    animal-mammal
    1             1F415  fully-qualified     🐕           dog  Animals & Nature    animal-mammal
    2             1F9AE  fully-qualified     🦮     guide dog  Animals & Nature    animal-mammal
    3  1F415 200D 1F9BA  fully-qualified     🐕‍🦺   service dog  Animals & Nature    animal-mammal
    4             1F32D  fully-qualified     🌭       hot dog      Food & Drink    food-prepared

    >>> blue = adv.emoji_search('blue')
    >>> blue
      codepoint           status emoji                name               group     sub_group
    0     1F499  fully-qualified     💙          blue heart  Smileys & Emotion       emotion
    1     1FAD0  fully-qualified     🫐         blueberries       Food & Drink    food-fruit
    2     1F4D8  fully-qualified     📘           blue book            Objects    book-paper
    3     1F535  fully-qualified     🔵         blue circle            Symbols     geometric
    4     1F7E6  fully-qualified     🟦         blue square            Symbols     geometric
    5     1F537  fully-qualified     🔷  large blue diamond            Symbols     geometric
    6     1F539  fully-qualified     🔹  small blue diamond            Symbols     geometric
    """
    emoji_df = pd.read_parquet("advertools/emoji_df.parquet")
    result_index = (
        emoji_df.select_dtypes("object")
        .apply(lambda series: series.astype(str).str.contains(regex, case=False))
        .apply(lambda row: any(row), axis=1)
    )
    return emoji_df[result_index].reset_index(drop=True)
